@@ -126,7 +126,7 @@ show_in_editor (const gchar * program_name,
       dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
                                        GTK_DIALOG_MODAL,
                                        GTK_BUTTONS_CLOSE,
-                                       _("Please install \"%s\" to be able to show the file"),
+                                       _("Please install “%s” to be able to show the file"),
                                        program_name);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
@@ -423,17 +423,8 @@ gtr_code_view_plugin_dispose (GObject *object)
 {
   GtrCodeViewPluginPrivate *priv = GTR_CODE_VIEW_PLUGIN (object)->priv;
 
-  if (priv->settings != NULL)
-    {
-      g_object_unref (priv->settings);
-      priv->settings = NULL;
-    }
-
-  if (priv->window != NULL)
-    {
-      g_object_unref (priv->window);
-      priv->window = NULL;
-    }
+  g_clear_object (&priv->settings);
+  g_clear_object (&priv->window);
 
   G_OBJECT_CLASS (gtr_code_view_plugin_parent_class)->dispose (object);
 }
