@@ -55,31 +55,28 @@ static void load_file_list (GtrWindow * window, const GSList * uris);
 gboolean
 gtr_open (GFile * location, GtrWindow * window, GError ** error)
 {
-  GtrHeader *header;
   GtrPo *po;
   GtrTab *tab;
   GList *current;
   GtrView *active_view;
-  const gchar *project_id;
 
   /*
    * If the filename can't be opened, pass the error back to the caller
    * to handle.
    */
+
   po = gtr_po_new ();
-  gtr_po_parse (po, location, error);
+  if (!gtr_po_parse (po, location, error)) {
+    gtr_window_show_projects (window);
+    // TODO: show error message
+    return FALSE;
+  }
 
   if ((*error != NULL)
-      && (((GError *) * error)->code != GTR_PO_ERROR_RECOVERY))
+      && (((GError *) * error)->code != GTR_PO_ERROR_RECOVERY)) {
+    gtr_window_show_projects (window);
     return FALSE;
-
-  header = gtr_po_get_header (po);
-  project_id = gtr_header_get_prj_id_version (header);
-
-  /*
-   * If not a crash/temporary file, add to the history.
-   */
-  _gtr_recent_add (window, location, (gchar *)project_id);
+  }
 
   /*
    * Create a page to add to our list of open files
@@ -108,6 +105,8 @@ gtr_open (GFile * location, GtrWindow * window, GError ** error)
                                      (gdouble)
                                      gtr_po_get_messages_count (po));
 
+  gtr_window_show_poeditor (window);
+
   return TRUE;
 }
 
@@ -318,7 +317,7 @@ gtr_save_file_as_dialog (GtkAction * action, GtrWindow * window)
 
   dialog = gtr_file_chooser_new (GTK_WINDOW (window),
                                  FILESEL_SAVE,
-                                 _("Save file as..."),
+                                 _("Save file as…"),
                                  _gtr_application_get_last_dir (GTR_APP));
 
   gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog),
@@ -414,6 +413,9 @@ load_file_list (GtrWindow * window, const GSList * locations)
 
   g_return_if_fail ((locations != NULL) && (locations->data != NULL));
 
+  // removing other tabs, for now on, we'll using single tab and multiples windows
+  gtr_window_remove_all_pages (window);
+
   /* Remove the uris corresponding to documents already open
    * in "window" and remove duplicates from "uris" list */
   l = locations;
