@@ -34,7 +34,6 @@
 #include "gtr-utils.h"
 #include "gtr-window.h"
 #include "gtr-preferences-dialog.h"
-#include "egg-toolbars-model.h"
 
 #include <glib.h>
 #include <glib-object.h>
@@ -50,29 +49,20 @@
 #include <gdk/gdkx.h>
 #endif
 
-#define GTR_APPLICATION_GET_PRIVATE(object)	(G_TYPE_INSTANCE_GET_PRIVATE ( \
-					 (object),	\
-					 GTR_TYPE_APPLICATION,     \
-					 GtrApplicationPrivate))
-
-G_DEFINE_TYPE (GtrApplication, gtr_application, GTK_TYPE_APPLICATION)
-
-struct _GtrApplicationPrivate
+typedef struct
 {
   GSettings *settings;
   GSettings *window_settings;
+  GtkCssProvider *provider;
 
   GtrWindow *active_window;
 
-  gchar *toolbars_file;
-  EggToolbarsModel *toolbars_model;
-
-  GtkIconFactory *icon_factory;
-
   gchar *last_dir;
 
   guint first_run : 1;
-};
+} GtrApplicationPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (GtrApplication, gtr_application, GTK_TYPE_APPLICATION)
 
 static gboolean
 ensure_user_config_dir (void)
@@ -140,7 +130,8 @@ static void
 set_active_window (GtrApplication *app,
                    GtrWindow      *window)
 {
-  app->priv->active_window = window;
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  priv->active_window = window;
 }
 
 static gboolean
@@ -160,23 +151,20 @@ static void
 on_window_destroy_cb (GtrWindow *window, GtrApplication *app)
 {
   GList *windows;
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
   windows = gtk_application_get_windows (GTK_APPLICATION (app));
 
-  if (window == app->priv->active_window)
+  if (window == priv->active_window)
     set_active_window (app, windows != NULL ? windows->data : NULL);
 }
 
 static void
 gtr_application_init (GtrApplication *application)
 {
-  GtrApplicationPrivate *priv;
   const gchar *gtr_folder;
-  gchar *path_default_gtr_toolbar;
   gchar *profiles_file;
-
-  application->priv = GTR_APPLICATION_GET_PRIVATE (application);
-  priv = application->priv;
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (application);
 
   priv->active_window = NULL;
   priv->last_dir = NULL;
@@ -196,46 +184,22 @@ gtr_application_init (GtrApplication *application)
     priv->first_run = TRUE;
   g_free (profiles_file);
 
-  priv->toolbars_model = egg_toolbars_model_new ();
-
-  priv->toolbars_file = g_build_filename (gtr_folder,
-                                          "gtr-toolbar.xml", NULL);
-
-  path_default_gtr_toolbar = gtr_dirs_get_ui_file ("gtr-toolbar.xml");
-
-  egg_toolbars_model_load_names (priv->toolbars_model,
-                                 path_default_gtr_toolbar);
-
-  if (!egg_toolbars_model_load_toolbars (priv->toolbars_model,
-                                         priv->toolbars_file))
-    {
-      egg_toolbars_model_load_toolbars (priv->toolbars_model,
-                                        path_default_gtr_toolbar);
-    }
-
-  g_free (path_default_gtr_toolbar);
-
-  egg_toolbars_model_set_flags (priv->toolbars_model, 0,
-                                EGG_TB_MODEL_NOT_REMOVABLE);
+  /* Custom css */
+  priv->provider = gtk_css_provider_new ();
+  gtk_css_provider_load_from_resource (priv->provider, "/org/gnome/translator/styles.css");
 
   load_accels ();
-
-  /* Create Icon factory */
-  application->priv->icon_factory = gtk_icon_factory_new ();
-  gtk_icon_factory_add_default (application->priv->icon_factory);
 }
 
 static void
 gtr_application_dispose (GObject * object)
 {
-  GtrApplicationPrivate *priv = GTR_APPLICATION (object)->priv;
-
-  DEBUG_PRINT ("Disposing app");
+  GtrApplication *app = GTR_APPLICATION (object);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
   g_clear_object (&priv->settings);
   g_clear_object (&priv->window_settings);
-  g_clear_object (&priv->icon_factory);
-  g_clear_object (&priv->toolbars_model);
+  g_clear_object (&priv->provider);
 
   G_OBJECT_CLASS (gtr_application_parent_class)->dispose (object);
 }
@@ -244,9 +208,9 @@ static void
 gtr_application_finalize (GObject *object)
 {
   GtrApplication *app = GTR_APPLICATION (object);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  g_free (app->priv->last_dir);
-  g_free (app->priv->toolbars_file);
+  g_free (priv->last_dir);
 
   G_OBJECT_CLASS (gtr_application_parent_class)->finalize (object);
 }
@@ -263,13 +227,80 @@ new_window_activated (GSimpleAction *action,
   gtk_application_add_window (GTK_APPLICATION (app), GTK_WINDOW (window));
 }
 
+static void
+find_activated (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+
+  _gtr_actions_search_find (NULL, priv->active_window);
+}
+
+static void
+find_and_replace_activated (GSimpleAction *action,
+                            GVariant      *parameter,
+                            gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+
+  _gtr_actions_search_replace (NULL, priv->active_window);
+}
+
 static void
 preferences_activated (GSimpleAction *action,
                        GVariant      *parameter,
                        gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  gtr_show_preferences_dialog (app->priv->active_window);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_show_preferences_dialog (priv->active_window);
+}
+
+static void
+edit_header_activated (GSimpleAction *action,
+                       GVariant      *parameter,
+                       gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_actions_edit_header (NULL, priv->active_window);
+}
+
+static void
+shortcuts_activated (GSimpleAction *action,
+                     GVariant      *parameter,
+                     gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  static GtkWidget *shortcuts_window;
+  GtkWindow *window = GTK_WINDOW (priv->active_window);
+
+  if (shortcuts_window == NULL)
+    {
+      GtkBuilder *builder;
+
+      builder = gtk_builder_new_from_resource ("/org/gnome/translator/help-overlay.ui");
+      shortcuts_window = GTK_WIDGET (gtk_builder_get_object (builder, "help_overlay"));
+
+      g_signal_connect (shortcuts_window,
+                "destroy",
+                G_CALLBACK (gtk_widget_destroyed),
+                &shortcuts_window);
+
+      g_object_unref (builder);
+    }
+
+    if (window != gtk_window_get_transient_for (GTK_WINDOW (shortcuts_window)))
+      {
+        gtk_window_set_transient_for (GTK_WINDOW (shortcuts_window), GTK_WINDOW (window));
+      }
+
+  gtk_widget_show_all (shortcuts_window);
+  gtk_window_present (GTK_WINDOW (shortcuts_window));
 }
 
 static void
@@ -278,7 +309,8 @@ help_activated (GSimpleAction *action,
                 gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  gtr_show_help (app->priv->active_window);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_show_help (priv->active_window);
 }
 
 static void
@@ -287,7 +319,8 @@ about_activated (GSimpleAction *action,
                  gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  gtr_about_dialog (app->priv->active_window);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_about_dialog (priv->active_window);
 }
 
 static void
@@ -310,23 +343,217 @@ quit_activated (GSimpleAction *action,
   g_application_quit (G_APPLICATION (app));
 }
 
+static void
+saveas_activated (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_save_file_as_dialog (NULL, priv->active_window);
+}
+
+static void
+save_activated (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_save_current_file_dialog (NULL, priv->active_window);
+}
+
+static void
+open_activated (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_open_file_dialog (NULL, priv->active_window);
+}
+
+static void
+undo_activated (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_actions_edit_undo (NULL, priv->active_window);
+}
+
+static void
+redo_activated (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_actions_edit_redo (NULL, priv->active_window);
+}
+
+static void
+prev_activated (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_message_go_to_previous (NULL, priv->active_window);
+}
+
+static void
+next_activated (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_message_go_to_next (NULL, priv->active_window);
+}
+
+static void
+prev_no_activated (GSimpleAction *action,
+                   GVariant      *parameter,
+                   gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_message_go_to_prev_fuzzy_or_untranslated (NULL, priv->active_window);
+}
+
+static void
+next_no_activated (GSimpleAction *action,
+                   GVariant      *parameter,
+                   gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_message_go_to_next_fuzzy_or_untranslated (NULL, priv->active_window);
+}
+
+static void
+build_tm_activated (GSimpleAction *action,
+                    GVariant      *parameter,
+                    gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  GtrWindow *w = GTR_WINDOW (priv->active_window);
+  gtr_window_show_tm_dialog (w);
+}
+
+static void
+tm_activated (GSimpleAction *action,
+              GVariant      *parameter,
+              gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  GtrWindow *w = GTR_WINDOW (priv->active_window);
+  gtr_window_tm_keybind (w, action);
+}
+
+static void
+toggle_fuzzy_activated (GSimpleAction *action,
+                        GVariant      *parameter,
+                        gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  GtrWindow *w = GTR_WINDOW (priv->active_window);
+  gtr_message_status_toggle_fuzzy (NULL, w);
+}
+
+static void
+sort_by_activated (GSimpleAction *action,
+                   GVariant      *parameter,
+                   gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  GtrWindow *w;
+  GtrTab *tab;
+
+  GVariant *st;
+  gint sortby = 0;
+
+  g_object_get (G_OBJECT (action), "state", &st, NULL);
+  sortby = g_variant_get_int32 (st);
+
+  w = GTR_WINDOW (priv->active_window);
+  g_return_if_fail (w != NULL);
+  tab = gtr_window_get_active_tab (w);
+  g_return_if_fail (tab != NULL);
+  gtr_tab_sort_by (tab, (GtrMessageTableSortBy)sortby);
+}
+
 static GActionEntry app_entries[] = {
+  { "save", save_activated, NULL, NULL, NULL },
+  { "saveas", saveas_activated, NULL, NULL, NULL },
+  { "open", open_activated, NULL, NULL, NULL },
+
+  { "undo", undo_activated, NULL, NULL, NULL },
+  { "redo", redo_activated, NULL, NULL, NULL },
+
+  { "prev", prev_activated, NULL, NULL, NULL },
+  { "next", next_activated, NULL, NULL, NULL },
+
+  { "prev_no", prev_no_activated, NULL, NULL, NULL },
+  { "next_no", next_no_activated, NULL, NULL, NULL },
+
+  { "fuzzy", toggle_fuzzy_activated, NULL, NULL, NULL },
+
+  // sort actions
+  { "sort_by_id", sort_by_activated, NULL, "0", NULL },
+  { "sort_by_status", sort_by_activated, NULL, "1", NULL },
+  { "sort_by_status_desc", sort_by_activated, NULL, "2", NULL },
+  { "sort_by_msgid", sort_by_activated, NULL, "3", NULL },
+  { "sort_by_msgid_desc", sort_by_activated, NULL, "4", NULL },
+  { "sort_by_translated", sort_by_activated, NULL, "5", NULL },
+  { "sort_by_translated_desc", sort_by_activated, NULL, "6", NULL },
+
+  { "build_tm", build_tm_activated, NULL, NULL, NULL },
+  { "tm_1", tm_activated, NULL, NULL, NULL },
+  { "tm_2", tm_activated, NULL, NULL, NULL },
+  { "tm_3", tm_activated, NULL, NULL, NULL },
+  { "tm_4", tm_activated, NULL, NULL, NULL },
+  { "tm_5", tm_activated, NULL, NULL, NULL },
+  { "tm_6", tm_activated, NULL, NULL, NULL },
+  { "tm_7", tm_activated, NULL, NULL, NULL },
+  { "tm_8", tm_activated, NULL, NULL, NULL },
+  { "tm_9", tm_activated, NULL, NULL, NULL },
+
+  { "find_and_replace", find_and_replace_activated, NULL, NULL, NULL },
+  { "find", find_activated, NULL, NULL, NULL },
   { "new_window", new_window_activated, NULL, NULL, NULL },
   { "preferences", preferences_activated, NULL, NULL, NULL },
+  { "edit_header", edit_header_activated, NULL, NULL, NULL },
+  { "shortcuts", shortcuts_activated, NULL, NULL, NULL },
   { "help", help_activated, NULL, NULL, NULL },
   { "about", about_activated, NULL, NULL, NULL },
   { "quit", quit_activated, NULL, NULL, NULL }
 };
 
+static void
+set_kb (GApplication *app, gchar *action, gchar *accel)
+{
+  const gchar *keys[] = {accel, NULL};
+  gtk_application_set_accels_for_action(GTK_APPLICATION (app), action, keys);
+}
+
 static void
 gtr_application_startup (GApplication *application)
 {
   GtkBuilder *builder;
+  GtrApplication *app = GTR_APPLICATION (application);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
   G_APPLICATION_CLASS (gtr_application_parent_class)->startup (application);
 
-  g_set_application_name (_("Gtranslator"));
-  gtk_window_set_default_icon_name ("gtranslator");
+  g_set_application_name (_("Translation Editor"));
+  gtk_window_set_default_icon_name (PACKAGE_APPID);
 
   /* We set the default icon dir */
   gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
@@ -335,11 +562,43 @@ gtr_application_startup (GApplication *application)
   g_action_map_add_action_entries (G_ACTION_MAP (application), app_entries,
                                    G_N_ELEMENTS (app_entries), application);
 
+  // keybindings
+  set_kb (application, "app.open", "<Ctrl>o");
+  set_kb (application, "app.save", "<Ctrl>s");
+  set_kb (application, "app.saveas", "<Ctrl><Shift>s");
+  set_kb (application, "app.preferences", "<Ctrl>p");
+
+  set_kb (application, "app.undo", "<Ctrl>z");
+  set_kb (application, "app.redo", "<Ctrl><Shift>z");
+
+  set_kb (application, "app.prev", "<Alt>Left");
+  set_kb (application, "app.next", "<Alt>Right");
+  set_kb (application, "app.prev_no", "<Alt>Page_Up");
+  set_kb (application, "app.next_no", "<Alt>Page_Down");
+
+  set_kb (application, "app.fuzzy", "<Ctrl>u");
+  set_kb (application, "app.find", "<Ctrl>f");
+  set_kb (application, "app.find_and_replace", "<Ctrl>h");
+
+  set_kb (application, "app.build_tm", "<Ctrl>plus");
+  set_kb (application, "app.tm_1", "<Ctrl>1");
+  set_kb (application, "app.tm_2", "<Ctrl>2");
+  set_kb (application, "app.tm_3", "<Ctrl>3");
+  set_kb (application, "app.tm_4", "<Ctrl>4");
+  set_kb (application, "app.tm_5", "<Ctrl>5");
+  set_kb (application, "app.tm_6", "<Ctrl>6");
+  set_kb (application, "app.tm_7", "<Ctrl>7");
+  set_kb (application, "app.tm_8", "<Ctrl>8");
+  set_kb (application, "app.tm_9", "<Ctrl>9");
+
   builder = gtk_builder_new ();
-  gtk_builder_add_from_resource (builder, "/org/gnome/gtranslator/ui/gtranslator-menu.ui", NULL);
+  gtk_builder_add_from_resource (builder, "/org/gnome/translator/gtranslator-menu.ui", NULL);
   gtk_application_set_app_menu (GTK_APPLICATION (application),
                                 G_MENU_MODEL (gtk_builder_get_object (builder, "appmenu")));
   g_object_unref (builder);
+
+  gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
+                                             GTK_STYLE_PROVIDER (priv->provider), 600);
 }
 
 static void
@@ -347,7 +606,8 @@ gtr_application_setup_window (GApplication *application,
                               GFile       **files,
                               gint          n_files)
 {
-  GtrApplicationPrivate *priv = GTR_APPLICATION (application)->priv;
+  GtrApplication *app = GTR_APPLICATION (application);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
   GtrWindow *window;
   GSList *file_list = NULL;
 
@@ -364,6 +624,13 @@ gtr_application_setup_window (GApplication *application,
   window = gtr_application_create_window (GTR_APPLICATION (application));
   gtk_application_add_window (GTK_APPLICATION (application), GTK_WINDOW (window));
 
+  /** loading custom styles **/
+  if (g_strrstr (PACKAGE_APPID, "Devel") != NULL)
+    {
+      GtkStyleContext *ctx = gtk_widget_get_style_context (GTK_WIDGET (window));
+      gtk_style_context_add_class (ctx, "devel");
+    }
+
   /* If it is the first run, the default directory was created in this
    * run, then we show the First run Assistant
    */
@@ -408,8 +675,6 @@ gtr_application_class_init (GtrApplicationClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GApplicationClass *application_class = G_APPLICATION_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GtrApplicationPrivate));
-
   object_class->dispose = gtr_application_dispose;
   object_class->finalize = gtr_application_finalize;
 
@@ -423,7 +688,7 @@ GtrApplication *
 _gtr_application_new ()
 {
   return GTR_APPLICATION (g_object_new (GTR_TYPE_APPLICATION,
-                                        "application-id", "org.gnome.Gtranslator",
+                                        "application-id", PACKAGE_APPID,
                                         "flags", G_APPLICATION_HANDLES_OPEN,
                                         NULL));
 }
@@ -442,16 +707,17 @@ gtr_application_create_window (GtrApplication *app)
   GtrWindow *window;
   GdkWindowState state;
   gint w, h;
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
   g_return_val_if_fail (GTR_IS_APPLICATION (app), NULL);
 
   window = g_object_new (GTR_TYPE_WINDOW, "application", app, NULL);
   set_active_window (app, window);
 
-  state = g_settings_get_int (app->priv->window_settings,
+  state = g_settings_get_int (priv->window_settings,
                               GTR_SETTINGS_WINDOW_STATE);
 
-  g_settings_get (app->priv->window_settings,
+  g_settings_get (priv->window_settings,
                   GTR_SETTINGS_WINDOW_SIZE,
                   "(ii)", &w, &h);
 
@@ -481,33 +747,6 @@ gtr_application_create_window (GtrApplication *app)
   return window;
 }
 
-/**
- * _gtr_application_get_toolbars_model:
- * @application: a #GtrApplication
- * 
- * Returns the toolbar model.
- * 
- * Returns: the toolbar model.
- */
-GObject *
-_gtr_application_get_toolbars_model (GtrApplication * application)
-{
-  return G_OBJECT (application->priv->toolbars_model);
-}
-
-/**
- * _gtr_application_save_toolbars_model:
- * @application: a #GtrApplication
- * 
- * Saves the toolbar model.
- */
-void
-_gtr_application_save_toolbars_model (GtrApplication * application)
-{
-  egg_toolbars_model_save_toolbars (application->priv->toolbars_model,
-                                    application->priv->toolbars_file, "1.0");
-}
-
 /**
  * gtr_application_get_views:
  * @app: the #GtranslationApplication
@@ -524,11 +763,12 @@ gtr_application_get_views (GtrApplication * app,
                            gboolean original, gboolean translated)
 {
   GList *res = NULL;
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
   g_return_val_if_fail (GTR_IS_APPLICATION (app), NULL);
 
   res = g_list_concat (res,
-                       gtr_window_get_all_views (GTR_WINDOW (app->priv->active_window),
+                       gtr_window_get_all_views (GTR_WINDOW (priv->active_window),
                                                  original, translated));
 
   return res;
@@ -543,46 +783,10 @@ gtr_application_get_views (GtrApplication * app,
 GtrWindow *
 gtr_application_get_active_window (GtrApplication * app)
 {
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
   g_return_val_if_fail (GTR_IS_APPLICATION (app), NULL);
 
-  return GTR_WINDOW (app->priv->active_window);
-}
-
-/**
- * gtr_application_register_icon:
- * @app: a #GtrApplication
- * @icon: the name of the icon
- * @stock_id: the stock id for the new icon
- * 
- * Registers a new @icon with the @stock_id.
- */
-void
-gtr_application_register_icon (GtrApplication *app,
-                               const gchar *icon, const gchar *stock_id)
-{
-  GtkIconSet *icon_set;
-  GtkIconSource *icon_source;
-  const gchar *pixmaps_dir;
-  gchar *path;
-  GdkPixbuf *pixbuf;
-
-  g_return_if_fail (GTR_IS_APPLICATION (app));
-  g_return_if_fail (icon != NULL && stock_id != NULL);
-
-  icon_source = gtk_icon_source_new ();
-  pixmaps_dir = gtr_dirs_get_gtr_pixmaps_dir ();
-  path = g_build_filename (pixmaps_dir, icon, NULL);
-
-  pixbuf = gdk_pixbuf_new_from_file (path, NULL);
-  if (pixbuf)
-    {
-      icon_set = gtk_icon_set_new_from_pixbuf (pixbuf);
-      gtk_icon_factory_add (app->priv->icon_factory, stock_id, icon_set);
-      g_object_unref (pixbuf);
-    }
-
-  g_free (path);
-  gtk_icon_source_free (icon_source);
+  return GTR_WINDOW (priv->active_window);
 }
 
 /**
@@ -594,9 +798,10 @@ gtr_application_register_icon (GtrApplication *app,
 const gchar *
 _gtr_application_get_last_dir (GtrApplication * app)
 {
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
   g_return_val_if_fail (GTR_IS_APPLICATION (app), NULL);
 
-  return app->priv->last_dir;
+  return priv->last_dir;
 }
 
 /**
@@ -608,15 +813,17 @@ _gtr_application_get_last_dir (GtrApplication * app)
 void
 _gtr_application_set_last_dir (GtrApplication * app, const gchar * last_dir)
 {
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
   g_return_if_fail (GTR_IS_APPLICATION (app));
 
-  app->priv->last_dir = g_strdup (last_dir);
+  priv->last_dir = g_strdup (last_dir);
 }
 
 GSettings *
 _gtr_application_get_settings (GtrApplication *app)
 {
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
   g_return_val_if_fail (GTR_IS_APPLICATION (app), NULL);
 
-  return app->priv->settings;
+  return priv->settings;
 }
