@@ -34,14 +34,7 @@
 #include "gtr-settings.h"
 #include "gtr-po.h"
 
-#define GTR_HEADER_DIALOG_GET_PRIVATE(object)	(G_TYPE_INSTANCE_GET_PRIVATE ( \
-						 (object),	\
-						 GTR_TYPE_HEADER_DIALOG,     \
-						 GtrHeaderDialogPrivate))
-
-G_DEFINE_TYPE (GtrHeaderDialog, gtr_header_dialog, GTK_TYPE_DIALOG)
-
-struct _GtrHeaderDialogPrivate
+typedef struct
 {
   GSettings *settings;
 
@@ -62,19 +55,28 @@ struct _GtrHeaderDialogPrivate
   GtkWidget *pot_date;
   GtkWidget *po_date;
   GtkWidget *language;
+  GtkWidget *lang_code;
   GtkWidget *lg_email;
   GtkWidget *charset;
   GtkWidget *encoding;
 
   GtrPo     *po;
+} GtrHeaderDialogPrivate;
+
+struct _GtrHeaderDialog
+{
+  GtkDialog parent_instance;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (GtrHeaderDialog, gtr_header_dialog, GTK_TYPE_DIALOG)
+
 static void
 gtr_header_dialog_dispose (GObject * object)
 {
   GtrHeaderDialog *dlg = GTR_HEADER_DIALOG (object);
+  GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  g_clear_object (&dlg->priv->settings);
+  g_clear_object (&priv->settings);
 
   G_OBJECT_CLASS (gtr_header_dialog_parent_class)->dispose (object);
 }
@@ -84,8 +86,6 @@ gtr_header_dialog_class_init (GtrHeaderDialogClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GtrHeaderDialogPrivate));
-
   object_class->dispose = gtr_header_dialog_dispose;
 }
 
@@ -94,19 +94,21 @@ take_my_options_checkbutton_toggled (GtkToggleButton * button,
                                      GtrHeaderDialog * dlg)
 {
   gboolean active;
+  GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  g_return_if_fail (button == GTK_TOGGLE_BUTTON (dlg->priv->take_my_options));
+  g_return_if_fail (button == GTK_TOGGLE_BUTTON (priv->take_my_options));
 
   active = gtk_toggle_button_get_active (button);
 
-  g_settings_set_boolean (dlg->priv->settings, GTR_SETTINGS_USE_PROFILE_VALUES,
+  g_settings_set_boolean (priv->settings, GTR_SETTINGS_USE_PROFILE_VALUES,
                           active);
 
-  gtk_widget_set_sensitive (dlg->priv->translator, !active);
-  gtk_widget_set_sensitive (dlg->priv->tr_email, !active);
-  gtk_widget_set_sensitive (dlg->priv->language, !active);
-  gtk_widget_set_sensitive (dlg->priv->lg_email, !active);
-  gtk_widget_set_sensitive (dlg->priv->encoding, !active);
+  gtk_widget_set_sensitive (priv->translator, !active);
+  gtk_widget_set_sensitive (priv->tr_email, !active);
+  gtk_widget_set_sensitive (priv->language, !active);
+  gtk_widget_set_sensitive (priv->lang_code, !active);
+  gtk_widget_set_sensitive (priv->lg_email, !active);
+  gtk_widget_set_sensitive (priv->encoding, !active);
 }
 
 static void
@@ -121,15 +123,16 @@ prj_comment_changed (GtkTextBuffer * buffer, GtrHeaderDialog * dlg)
 {
   GtkTextIter start, end;
   gchar *text;
+  GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
   gtk_text_buffer_get_bounds (buffer, &start, &end);
   text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
 
   if (text)
     {
-      gtr_header_set_comments (gtr_po_get_header (dlg->priv->po), text);
+      gtr_header_set_comments (gtr_po_get_header (priv->po), text);
       g_free (text);
-      po_state_set_modified (dlg->priv->po);
+      po_state_set_modified (priv->po);
     }
 }
 
@@ -137,13 +140,14 @@ static void
 prj_id_version_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
 {
   const gchar *text;
+  GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
   text = gtk_entry_get_text (GTK_ENTRY (widget));
 
   if (text)
     {
-      gtr_header_set_prj_id_version (gtr_po_get_header (dlg->priv->po), text);
-      po_state_set_modified (dlg->priv->po);
+      gtr_header_set_prj_id_version (gtr_po_get_header (priv->po), text);
+      po_state_set_modified (priv->po);
     }
 }
 
@@ -151,13 +155,14 @@ static void
 rmbt_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
 {
   const gchar *text;
+  GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
   text = gtk_entry_get_text (GTK_ENTRY (widget));
 
   if (text)
     {
-      gtr_header_set_rmbt (gtr_po_get_header (dlg->priv->po), text);
-      po_state_set_modified (dlg->priv->po);
+      gtr_header_set_rmbt (gtr_po_get_header (priv->po), text);
+      po_state_set_modified (priv->po);
     }
 }
 
@@ -165,29 +170,34 @@ static void
 translator_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
 {
   const gchar *name, *email;
+  GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  name = gtk_entry_get_text (GTK_ENTRY (dlg->priv->translator));
-  email = gtk_entry_get_text (GTK_ENTRY (dlg->priv->tr_email));
+  name = gtk_entry_get_text (GTK_ENTRY (priv->translator));
+  email = gtk_entry_get_text (GTK_ENTRY (priv->tr_email));
 
   if (name && email)
     {
-      gtr_header_set_translator (gtr_po_get_header (dlg->priv->po), name, email);
-      po_state_set_modified (dlg->priv->po);
+      gtr_header_set_translator (gtr_po_get_header (priv->po), name, email);
+      po_state_set_modified (priv->po);
     }
 }
 
 static void
 language_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
 {
-  const gchar *language, *lg_email;
+  const gchar *language, *lg_email, *lang_code;
+  GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  language = gtk_entry_get_text (GTK_ENTRY (dlg->priv->language));
-  lg_email = gtk_entry_get_text (GTK_ENTRY (dlg->priv->lg_email));
+  language = gtk_entry_get_text (GTK_ENTRY (priv->language));
+  lg_email = gtk_entry_get_text (GTK_ENTRY (priv->lg_email));
+  lang_code = gtk_entry_get_text (GTK_ENTRY (priv->lang_code));
 
   if (language && lg_email)
     {
-      gtr_header_set_language (gtr_po_get_header (dlg->priv->po), language, lg_email);
-      po_state_set_modified (dlg->priv->po);
+      gtr_header_set_language (gtr_po_get_header (priv->po),
+                               language, lang_code,
+                               lg_email);
+      po_state_set_modified (priv->po);
     }
 }
 
@@ -197,60 +207,64 @@ gtr_header_dialog_fill_from_header (GtrHeaderDialog * dlg)
   GtrHeader *header;
   GtkTextBuffer *buffer;
   gchar *text;
+  GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  header = gtr_po_get_header (dlg->priv->po);
+  header = gtr_po_get_header (priv->po);
 
   /* Project Information */
-  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (dlg->priv->prj_comment));
+  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->prj_comment));
   gtk_text_buffer_set_text (buffer, gtr_header_get_comments (header), -1);
 
   text = gtr_header_get_prj_id_version (header);
-  gtk_entry_set_text (GTK_ENTRY (dlg->priv->prj_id_version), text);
+  gtk_entry_set_text (GTK_ENTRY (priv->prj_id_version), text);
   g_free (text);
 
   text = gtr_header_get_pot_date (header);
-  gtk_entry_set_text (GTK_ENTRY (dlg->priv->pot_date), text);
+  gtk_entry_set_text (GTK_ENTRY (priv->pot_date), text);
   g_free (text);
 
   text = gtr_header_get_po_date (header);
-  gtk_entry_set_text (GTK_ENTRY (dlg->priv->po_date), text);
+  gtk_entry_set_text (GTK_ENTRY (priv->po_date), text);
   g_free (text);
 
   text = gtr_header_get_rmbt (header);
-  gtk_entry_set_text (GTK_ENTRY (dlg->priv->rmbt), text);
+  gtk_entry_set_text (GTK_ENTRY (priv->rmbt), text);
   g_free (text);
 
   /* Translator and Language Information */
   text = gtr_header_get_translator (header);
-  gtk_entry_set_text (GTK_ENTRY (dlg->priv->translator), text);
+  gtk_entry_set_text (GTK_ENTRY (priv->translator), text);
   g_free (text);
 
   text = gtr_header_get_tr_email (header);
-  gtk_entry_set_text (GTK_ENTRY (dlg->priv->tr_email), text);
+  gtk_entry_set_text (GTK_ENTRY (priv->tr_email), text);
   g_free (text);
 
   text = gtr_header_get_language (header);
-  gtk_entry_set_text (GTK_ENTRY (dlg->priv->language), text);
+  gtk_entry_set_text (GTK_ENTRY (priv->language), text);
+  g_free (text);
+
+  text = gtr_header_get_language_code (header);
+  gtk_entry_set_text (GTK_ENTRY (priv->lang_code), text);
   g_free (text);
 
   text = gtr_header_get_lg_email (header);
-  gtk_entry_set_text (GTK_ENTRY (dlg->priv->lg_email), text);
+  gtk_entry_set_text (GTK_ENTRY (priv->lg_email), text);
   g_free (text);
 
   text = gtr_header_get_charset (header);
-  gtk_entry_set_text (GTK_ENTRY (dlg->priv->charset), text);
+  gtk_entry_set_text (GTK_ENTRY (priv->charset), text);
   g_free (text);
 
   text = gtr_header_get_encoding (header);
-  gtk_entry_set_text (GTK_ENTRY (dlg->priv->encoding), text);
+  gtk_entry_set_text (GTK_ENTRY (priv->encoding), text);
   g_free (text);
 }
 
 static void
 gtr_header_dialog_init (GtrHeaderDialog * dlg)
 {
-  GtrHeaderDialogPrivate *priv;
-  GtkWidget *action_area;
+  GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
   GtkBox *content_area;
   GtkBuilder *builder;
   gchar *root_objects[] = {
@@ -258,78 +272,74 @@ gtr_header_dialog_init (GtrHeaderDialog * dlg)
     NULL
   };
 
-  dlg->priv = GTR_HEADER_DIALOG_GET_PRIVATE (dlg);
-  priv = dlg->priv;
-
-  dlg->priv->settings = g_settings_new ("org.gnome.gtranslator.preferences.files");
+  priv->settings = g_settings_new ("org.gnome.gtranslator.preferences.files");
 
   gtk_dialog_add_buttons (GTK_DIALOG (dlg),
-                          GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
+                          _("_Close"), GTK_RESPONSE_CLOSE, NULL);
 
   gtk_window_set_title (GTK_WINDOW (dlg), _("Edit Header"));
   gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
 
-  action_area = gtk_dialog_get_action_area (GTK_DIALOG (dlg));
   content_area = GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg)));
 
   gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);
   gtk_box_set_spacing (content_area, 2);
-  gtk_container_set_border_width (GTK_CONTAINER (action_area), 5);
-  gtk_box_set_spacing (GTK_BOX (action_area), 4);
 
   g_signal_connect (dlg, "response", G_CALLBACK (gtk_widget_destroy), NULL);
 
   builder = gtk_builder_new ();
-  gtk_builder_add_objects_from_resource (builder, "/org/gnome/gtranslator/ui/gtr-header-dialog.ui",
+  gtk_builder_add_objects_from_resource (builder, "/org/gnome/translator/gtr-header-dialog.ui",
                                          root_objects, NULL);
 
   priv->main_box = GTK_WIDGET (gtk_builder_get_object (builder, "main_box"));
   g_object_ref (priv->main_box);
-  dlg->priv->notebook = GTK_WIDGET (gtk_builder_get_object (builder, "notebook"));
-  dlg->priv->lang_vbox = GTK_WIDGET (gtk_builder_get_object (builder, "lang_vbox"));
-  dlg->priv->prj_id_version = GTK_WIDGET (gtk_builder_get_object (builder, "prj_id_version"));
-  dlg->priv->rmbt = GTK_WIDGET (gtk_builder_get_object (builder, "rmbt"));
-  dlg->priv->prj_comment = GTK_WIDGET (gtk_builder_get_object (builder, "prj_comment"));
-  dlg->priv->take_my_options = GTK_WIDGET (gtk_builder_get_object (builder, "take_my_options"));
-  dlg->priv->translator = GTK_WIDGET (gtk_builder_get_object (builder, "tr_name"));
-  dlg->priv->tr_email = GTK_WIDGET (gtk_builder_get_object (builder, "tr_email"));
-  dlg->priv->pot_date = GTK_WIDGET (gtk_builder_get_object (builder, "pot_date"));
-  dlg->priv->po_date = GTK_WIDGET (gtk_builder_get_object (builder, "po_date"));
-  dlg->priv->language = GTK_WIDGET (gtk_builder_get_object (builder, "language_entry"));
-  dlg->priv->lg_email = GTK_WIDGET (gtk_builder_get_object (builder, "lg_email_entry"));
-  dlg->priv->charset = GTK_WIDGET (gtk_builder_get_object (builder, "charset_entry"));
-  dlg->priv->encoding = GTK_WIDGET (gtk_builder_get_object (builder, "encoding_entry"));
+  priv->notebook = GTK_WIDGET (gtk_builder_get_object (builder, "notebook"));
+  priv->lang_vbox = GTK_WIDGET (gtk_builder_get_object (builder, "lang_vbox"));
+  priv->prj_id_version = GTK_WIDGET (gtk_builder_get_object (builder, "prj_id_version"));
+  priv->rmbt = GTK_WIDGET (gtk_builder_get_object (builder, "rmbt"));
+  priv->prj_comment = GTK_WIDGET (gtk_builder_get_object (builder, "prj_comment"));
+  priv->take_my_options = GTK_WIDGET (gtk_builder_get_object (builder, "take_my_options"));
+  priv->translator = GTK_WIDGET (gtk_builder_get_object (builder, "tr_name"));
+  priv->tr_email = GTK_WIDGET (gtk_builder_get_object (builder, "tr_email"));
+  priv->pot_date = GTK_WIDGET (gtk_builder_get_object (builder, "pot_date"));
+  priv->po_date = GTK_WIDGET (gtk_builder_get_object (builder, "po_date"));
+  priv->language = GTK_WIDGET (gtk_builder_get_object (builder, "language_entry"));
+  priv->lang_code = GTK_WIDGET (gtk_builder_get_object (builder, "language_code_entry"));
+  priv->lg_email = GTK_WIDGET (gtk_builder_get_object (builder, "lg_email_entry"));
+  priv->charset = GTK_WIDGET (gtk_builder_get_object (builder, "charset_entry"));
+  priv->encoding = GTK_WIDGET (gtk_builder_get_object (builder, "encoding_entry"));
   g_object_unref (builder);
 
-  gtk_box_pack_start (content_area, dlg->priv->main_box, FALSE, FALSE, 0);
+  gtk_box_pack_start (content_area, priv->main_box, FALSE, FALSE, 0);
 
-  gtk_container_set_border_width (GTK_CONTAINER (dlg->priv->notebook), 5);
+  gtk_container_set_border_width (GTK_CONTAINER (priv->notebook), 5);
 
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->take_my_options),
-                                g_settings_get_boolean (dlg->priv->settings,
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->take_my_options),
+                                g_settings_get_boolean (priv->settings,
                                                         GTR_SETTINGS_USE_PROFILE_VALUES));
 
-  gtk_text_view_set_editable (GTK_TEXT_VIEW (dlg->priv->prj_comment), TRUE);
+  gtk_text_view_set_editable (GTK_TEXT_VIEW (priv->prj_comment), TRUE);
 
-  gtk_widget_set_sensitive (dlg->priv->pot_date, FALSE);
-  gtk_widget_set_sensitive (dlg->priv->po_date, FALSE);
-  gtk_widget_set_sensitive (dlg->priv->charset, FALSE);
+  gtk_widget_set_sensitive (priv->pot_date, FALSE);
+  gtk_widget_set_sensitive (priv->po_date, FALSE);
+  gtk_widget_set_sensitive (priv->charset, FALSE);
 
   if (gtk_toggle_button_get_active
-      (GTK_TOGGLE_BUTTON (dlg->priv->take_my_options)))
+      (GTK_TOGGLE_BUTTON (priv->take_my_options)))
     {
       gboolean active;
 
       active =
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
-                                      (dlg->priv->take_my_options));
+                                      (priv->take_my_options));
 
-      gtk_widget_set_sensitive (dlg->priv->translator, !active);
-      gtk_widget_set_sensitive (dlg->priv->tr_email, !active);
-      gtk_widget_set_sensitive (dlg->priv->language, !active);
-      gtk_widget_set_sensitive (dlg->priv->lg_email, !active);
-      gtk_widget_set_sensitive (dlg->priv->encoding, !active);
+      gtk_widget_set_sensitive (priv->translator, !active);
+      gtk_widget_set_sensitive (priv->tr_email, !active);
+      gtk_widget_set_sensitive (priv->language, !active);
+      gtk_widget_set_sensitive (priv->lang_code, !active);
+      gtk_widget_set_sensitive (priv->lg_email, !active);
+      gtk_widget_set_sensitive (priv->encoding, !active);
     }
 }
 
@@ -338,46 +348,50 @@ set_default_values (GtrHeaderDialog * dlg, GtrWindow * window)
 {
   GtkTextBuffer *buffer;
   GtrTab *tab;
+  GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
   /* Write header's values on Header dialog */
   tab = gtr_window_get_active_tab (window);
-  dlg->priv->po = gtr_tab_get_po (tab);
+  priv->po = gtr_tab_get_po (tab);
   gtr_header_dialog_fill_from_header (GTR_HEADER_DIALOG (dlg));
 
   /*Connect signals */
-  g_signal_connect (dlg->priv->take_my_options, "toggled",
+  g_signal_connect (priv->take_my_options, "toggled",
                     G_CALLBACK (take_my_options_checkbutton_toggled), dlg);
 
-  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (dlg->priv->prj_comment));
+  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->prj_comment));
 
   g_signal_connect (buffer, "changed", G_CALLBACK (prj_comment_changed), dlg);
 
   /* Connect signals to edit Project information on Header dialog */
-  g_signal_connect (dlg->priv->prj_id_version, "changed",
+  g_signal_connect (priv->prj_id_version, "changed",
                     G_CALLBACK (prj_id_version_changed), dlg);
 
-  g_signal_connect (dlg->priv->rmbt, "changed",
+  g_signal_connect (priv->rmbt, "changed",
                     G_CALLBACK (rmbt_changed), dlg);
 
   /* Connect signals to edit Translator and Language information on Header dialog */
-  g_signal_connect (dlg->priv->translator, "changed",
+  g_signal_connect (priv->translator, "changed",
                     G_CALLBACK (translator_changed), dlg);
 
-  g_signal_connect (dlg->priv->tr_email, "changed",
+  g_signal_connect (priv->tr_email, "changed",
                     G_CALLBACK (translator_changed), dlg);
 
-  g_signal_connect (dlg->priv->language, "changed",
+  g_signal_connect (priv->language, "changed",
                     G_CALLBACK (language_changed), dlg);
 
-  g_signal_connect (dlg->priv->lg_email, "changed",
+  g_signal_connect (priv->lang_code, "changed",
+                    G_CALLBACK (language_changed), dlg);
+
+  g_signal_connect (priv->lg_email, "changed",
                     G_CALLBACK (language_changed), dlg);
 }
 
 void
 gtr_show_header_dialog (GtrWindow * window)
 {
-  static GtrHeaderDialog *dlg = NULL;
-  GtrTab *tab;
+  static GtkWidget *dlg = NULL;
+  GtrTab *tab = NULL;
 
   tab = gtr_window_get_active_tab (window);
   g_return_if_fail (tab != NULL);
@@ -386,20 +400,20 @@ gtr_show_header_dialog (GtrWindow * window)
 
   if (dlg == NULL)
     {
-      dlg = g_object_new (GTR_TYPE_HEADER_DIALOG, NULL);
+      dlg = GTK_WIDGET (g_object_new (GTR_TYPE_HEADER_DIALOG,
+                                      "use-header-bar", TRUE, NULL));
 
       g_signal_connect (dlg,
                         "destroy", G_CALLBACK (gtk_widget_destroyed), &dlg);
 
-      set_default_values (dlg, window);
+      set_default_values (GTR_HEADER_DIALOG (dlg), window);
 
       gtk_widget_show (GTK_WIDGET (dlg));
     }
 
-  if (GTK_WINDOW (window) != gtk_window_get_transient_for (GTK_WINDOW (dlg)))
-    {
-      gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (window));
-    }
+  gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (window));
+  gtk_window_set_type_hint (GTK_WINDOW (dlg), GDK_WINDOW_TYPE_HINT_DIALOG);
+  gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
 
   gtk_window_present (GTK_WINDOW (dlg));
 }
