@@ -36,22 +36,22 @@
 #include <glib-object.h>
 #include <string.h>
 
-#define GTR_HEADER_GET_PRIVATE(object)	(G_TYPE_INSTANCE_GET_PRIVATE ( \
-                                         (object), \
-                                         GTR_TYPE_HEADER, \
-                                         GtrHeaderPrivate))
-
-G_DEFINE_TYPE (GtrHeader, gtr_header, GTR_TYPE_MSG)
-
-struct _GtrHeaderPrivate
+typedef struct
 {
   GSettings *settings;
 
   GtrProfileManager *prof_manager;
   GtrProfile *profile;
   gint nplurals;
+} GtrHeaderPrivate;
+
+struct _GtrHeader
+{
+  GtrMsg parent_instance;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (GtrHeader, gtr_header, GTR_TYPE_MSG)
+
 static void
 gtr_header_set_field (GtrHeader * header,
                       const gchar * field, const gchar * data)
@@ -74,10 +74,11 @@ parse_nplurals (GtrHeader * header)
 {
   gchar *pointer, *plural_forms;
   gboolean use_profile_values;
+  GtrHeaderPrivate *priv = gtr_header_get_instance_private (header);
 
   plural_forms = gtr_header_get_plural_forms (header);
-  header->priv->nplurals = -1;
-  use_profile_values = g_settings_get_boolean (header->priv->settings,
+  priv->nplurals = -1;
+  use_profile_values = g_settings_get_boolean (priv->settings,
                                                GTR_SETTINGS_USE_PROFILE_VALUES);
 
   if (use_profile_values || !plural_forms)
@@ -85,8 +86,8 @@ parse_nplurals (GtrHeader * header)
       const gchar *plural_form = NULL;
       GtrProfile *profile;
 
-      if (header->priv->profile != NULL)
-        profile = header->priv->profile;
+      if (priv->profile != NULL)
+        profile = priv->profile;
       else
         {
           GtrProfileManager *prof_manager;
@@ -117,7 +118,7 @@ parse_nplurals (GtrHeader * header)
       while (*pointer != '\0' && *pointer != '=')
         pointer++;
 
-      if (pointer != '\0')
+      if (*pointer != '\0')
         {
           pointer++;
           while (*pointer != '\0' && *pointer == ' ')
@@ -129,10 +130,10 @@ parse_nplurals (GtrHeader * header)
       else
         return;
 
-      header->priv->nplurals = g_ascii_digit_value (*pointer);
+      priv->nplurals = g_ascii_digit_value (*pointer);
     }
 
-  /*g_message ("nplurals: %d", header->priv->nplurals); */
+  /*g_message ("nplurals: %d", priv->nplurals); */
 
   g_free (plural_forms);
 }
@@ -142,22 +143,23 @@ profile_removed_cb (GtrProfileManager *prof_manager,
                     GtrProfile        *profile,
                     GtrHeader         *header)
 {
-  if (profile == header->priv->profile)
-    header->priv->profile = NULL;
+  GtrHeaderPrivate *priv = gtr_header_get_instance_private (header);
+  if (profile == priv->profile)
+    priv->profile = NULL;
 }
 
 static void
 gtr_header_init (GtrHeader * header)
 {
-  header->priv = GTR_HEADER_GET_PRIVATE (header);
+  GtrHeaderPrivate *priv = gtr_header_get_instance_private (header);
 
-  header->priv->nplurals = -1;
-  header->priv->profile = NULL;
+  priv->nplurals = -1;
+  priv->profile = NULL;
 
-  header->priv->settings = g_settings_new ("org.gnome.gtranslator.preferences.files");
-  header->priv->prof_manager = gtr_profile_manager_get_default ();
+  priv->settings = g_settings_new ("org.gnome.gtranslator.preferences.files");
+  priv->prof_manager = gtr_profile_manager_get_default ();
 
-  g_signal_connect (header->priv->prof_manager, "profile-removed",
+  g_signal_connect (priv->prof_manager, "profile-removed",
                     G_CALLBACK (profile_removed_cb), header);
 }
 
@@ -165,10 +167,11 @@ static void
 gtr_header_dispose (GObject * object)
 {
   GtrHeader *header = GTR_HEADER (object);
+  GtrHeaderPrivate *priv = gtr_header_get_instance_private (header);
 
-  g_clear_object (&header->priv->settings);
-  g_clear_object (&header->priv->prof_manager);
-  g_clear_object (&header->priv->profile);
+  g_clear_object (&priv->settings);
+  g_clear_object (&priv->prof_manager);
+  g_clear_object (&priv->profile);
 
   G_OBJECT_CLASS (gtr_header_parent_class)->dispose (object);
 }
@@ -178,8 +181,6 @@ gtr_header_class_init (GtrHeaderClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GtrHeaderPrivate));
-
   object_class->dispose = gtr_header_dispose;
 }
 
@@ -385,6 +386,16 @@ gtr_header_get_language (GtrHeader * header)
   return language;
 }
 
+gchar *
+gtr_header_get_language_code (GtrHeader * header)
+{
+  gchar *language;
+  g_return_val_if_fail (GTR_IS_HEADER (header), NULL);
+  language = po_header_field (gtr_msg_get_msgstr (GTR_MSG (header)),
+                              "Language");
+  return language;
+}
+
 gchar *
 gtr_header_get_lg_email (GtrHeader * header)
 {
@@ -408,7 +419,9 @@ gtr_header_get_lg_email (GtrHeader * header)
 
 void
 gtr_header_set_language (GtrHeader * header,
-                         const gchar * language, const gchar * email)
+                         const gchar * language,
+                         const gchar * lang_code,
+                         const gchar * email)
 {
   gchar *lang_temp;
 
@@ -417,6 +430,7 @@ gtr_header_set_language (GtrHeader * header,
   lang_temp = g_strconcat (language, " <", email, ">", NULL);
 
   gtr_header_set_field (header, "Language-Team", lang_temp);
+  gtr_header_set_field (header, "Language", lang_code);
 
   g_free (lang_temp);
 }
@@ -536,10 +550,11 @@ gtr_header_set_plural_forms (GtrHeader * header, const gchar * plural_forms)
 gint
 gtr_header_get_nplurals (GtrHeader * header)
 {
+  GtrHeaderPrivate *priv = gtr_header_get_instance_private (header);
   g_return_val_if_fail (GTR_IS_HEADER (header), 1);
 
-  if (header->priv->nplurals > -1)
-    return header->priv->nplurals;
+  if (priv->nplurals > -1)
+    return priv->nplurals;
   else
     return 1;
 }
@@ -549,13 +564,14 @@ set_profile_values (GtrHeader *header)
 {
   GtrProfile *active_profile;
   gboolean use_profile_values;
+  GtrHeaderPrivate *priv = gtr_header_get_instance_private (header);
 
-  if (header->priv->profile != NULL)
-    active_profile = header->priv->profile;
+  if (priv->profile != NULL)
+    active_profile = priv->profile;
   else
-    active_profile = gtr_profile_manager_get_active_profile (header->priv->prof_manager);
+    active_profile = gtr_profile_manager_get_active_profile (priv->prof_manager);
 
-  use_profile_values = g_settings_get_boolean (header->priv->settings,
+  use_profile_values = g_settings_get_boolean (priv->settings,
                                                GTR_SETTINGS_USE_PROFILE_VALUES);
 
   if (use_profile_values && active_profile != NULL)
@@ -566,6 +582,7 @@ set_profile_values (GtrHeader *header)
                                  (active_profile));
       gtr_header_set_language (header,
                                gtr_profile_get_language_name (active_profile),
+                               gtr_profile_get_language_code (active_profile),
                                gtr_profile_get_group_email (active_profile));
       gtr_header_set_charset (header,
                               gtr_profile_get_charset (active_profile));
@@ -601,22 +618,24 @@ update_comments (GtrHeader *header, const gchar *comments)
 {
   GtrProfile *active_profile;
   GString *new_comments;
-  GString *years;
   gchar **comment_lines;
   gchar *translator;
   gchar *email;
   gchar *current_year;
+  gchar *first_year = NULL;
+  gchar *years = NULL;
   gboolean use_profile_values;
   gint i;
+  GtrHeaderPrivate *priv = gtr_header_get_instance_private (header);
 
-  if (header->priv->profile != NULL)
-    active_profile = header->priv->profile;
+  if (priv->profile != NULL)
+    active_profile = priv->profile;
   else
-    active_profile = gtr_profile_manager_get_active_profile (header->priv->prof_manager);
+    active_profile = gtr_profile_manager_get_active_profile (priv->prof_manager);
 
   current_year = gtr_utils_get_current_year ();
 
-  use_profile_values = g_settings_get_boolean (header->priv->settings,
+  use_profile_values = g_settings_get_boolean (priv->settings,
                                                GTR_SETTINGS_USE_PROFILE_VALUES);
 
   /* Save the previous translator to update the header's comment */
@@ -633,7 +652,6 @@ update_comments (GtrHeader *header, const gchar *comments)
 
   comment_lines = g_strsplit (comments, "\n", -1);
   new_comments = g_string_new ("");
-  years = g_string_new ("");
 
   for (i = 0; comment_lines != NULL && comment_lines[i] != NULL; i++)
     {
@@ -658,11 +676,27 @@ update_comments (GtrHeader *header, const gchar *comments)
               else
                 search = g_strdup (year_array[j]);
 
-              if ((g_strrstr (years->str, search) == NULL) &&
-                  (strcmp (search + 1, current_year) != 0))
+              // removing whitespaces. This will remove ^M chars that can cause
+              // problems
+              g_strstrip (search);
+
+              // looking for YEAR1-YEAR2.
+              if (g_strrstr (search, "-"))
                 {
-                  years = g_string_append (years, search);
-                  years = g_string_append_c (years, ',');
+                  gchar **array = g_strsplit (search, "-", 2);
+                  if (*array[0] != '\0' && strcmp (array[0], current_year) != 0)
+                    first_year = g_strdup (array[0]);
+
+                  g_strfreev (array);
+                  g_free (search);
+                  break;
+                }
+
+              if (*search != '\0' && strcmp (search, current_year) != 0)
+                {
+                  first_year = g_strdup (search);
+                  g_free (search);
+                  break;
                 }
 
               g_free (search);
@@ -679,17 +713,24 @@ update_comments (GtrHeader *header, const gchar *comments)
 
   g_strfreev (comment_lines);
 
-  g_string_append_printf (years, " %s.", current_year);
+  if (first_year && first_year != current_year)
+    {
+      years = g_strdup_printf ("%s-%s.", first_year, current_year);
+      g_free (first_year);
+    }
+  else
+    years = g_strdup_printf ("%s.", current_year);
 
   /* Remove all empty lines at the end */
   while (new_comments->str[new_comments->len - 1] == '\n')
     new_comments = g_string_truncate (new_comments, new_comments->len - 1);
 
   /* Add \n\n for an extra newline at the end of the comments */
-  g_string_append_printf (new_comments, "\n%s <%s>,%s\n\n",
-                          translator, email, years->str);
+  g_string_append_printf (new_comments, "\n%s <%s>, %s\n\n",
+                          translator, email, years);
 
-  g_string_free (years, TRUE);
+  g_free (years);
+  g_free (current_year);
 
   gtr_header_set_comments (header, new_comments->str);
 
@@ -732,9 +773,10 @@ void
 gtr_header_set_profile (GtrHeader  *header,
                         GtrProfile *profile)
 {
+  GtrHeaderPrivate *priv = gtr_header_get_instance_private (header);
   g_return_if_fail (GTR_IS_HEADER (header));
 
-  header->priv->profile = g_object_ref (profile);
+  priv->profile = g_object_ref (profile);
 }
 
 /**
@@ -748,7 +790,8 @@ gtr_header_set_profile (GtrHeader  *header,
 GtrProfile *
 gtr_header_get_profile (GtrHeader *header)
 {
+  GtrHeaderPrivate *priv = gtr_header_get_instance_private (header);
   g_return_val_if_fail (GTR_IS_HEADER (header), NULL);
 
-  return header->priv->profile;
+  return priv->profile;
 }
