@@ -40,20 +40,9 @@ G_BEGIN_DECLS
 #define GTR_IS_HEADER_CLASS(k)		(G_TYPE_CHECK_CLASS_TYPE ((k), GTR_TYPE_HEADER))
 #define GTR_HEADER_GET_CLASS(o)		(G_TYPE_INSTANCE_GET_CLASS ((o), GTR_TYPE_HEADER, GtrHeaderClass))
 
-/* Private structure type */
-typedef struct _GtrHeaderPrivate GtrHeaderPrivate;
-
 /* Main object structure */
 typedef struct _GtrHeader GtrHeader;
 
-struct _GtrHeader
-{
-  GtrMsg parent_instance;
-
-  /*< private > */
-  GtrHeaderPrivate *priv;
-};
-
 /* Class definition */
 typedef struct _GtrHeaderClass GtrHeaderClass;
 
@@ -98,6 +87,7 @@ gchar           *gtr_header_get_language             (GtrHeader *header);
 gchar           *gtr_header_get_lg_email             (GtrHeader *header);
 void             gtr_header_set_language             (GtrHeader   *header,
                                                       const gchar *language,
+                                                      const gchar *lang_code,
                                                       const gchar *email);
 
 gchar           *gtr_header_get_mime_version         (GtrHeader *header);
@@ -123,6 +113,8 @@ void             gtr_header_set_profile              (GtrHeader  *header,
                                                       GtrProfile *profile);
 GtrProfile      *gtr_header_get_profile              (GtrHeader *header);
 
+gchar           *gtr_header_get_language_code        (GtrHeader * header);
+
 G_END_DECLS
 
 #endif /* __HEADER_H__ */
