@@ -15,9 +15,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 /*
@@ -50,11 +49,7 @@ enum
 
 #define GTR_HISTORY_ENTRY_HISTORY_LENGTH_DEFAULT 10
 
-#define GTR_HISTORY_ENTRY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
-						GTR_TYPE_HISTORY_ENTRY, \
-						GtrHistoryEntryPrivate))
-
-struct _GtrHistoryEntryPrivate
+typedef struct
 {
   gchar *history_id;
   guint history_length;
@@ -62,16 +57,23 @@ struct _GtrHistoryEntryPrivate
   GtkEntryCompletion *completion;
 
   GSettings *settings;
+} GtrHistoryEntryPrivate;
+
+struct _GtrHistoryEntry
+{
+  GtkComboBoxText parent_instance;
 };
 
-G_DEFINE_TYPE (GtrHistoryEntry, gtr_history_entry, GTK_TYPE_COMBO_BOX_TEXT)
-     static void
-       gtr_history_entry_set_property (GObject * object,
-                                       guint prop_id,
-                                       const GValue * value,
-                                       GParamSpec * spec)
+G_DEFINE_TYPE_WITH_PRIVATE (GtrHistoryEntry, gtr_history_entry, GTK_TYPE_COMBO_BOX_TEXT)
+
+static void
+gtr_history_entry_set_property (GObject * object,
+                                guint prop_id,
+                                const GValue * value,
+                                GParamSpec * spec)
 {
-  GtrHistoryEntry *entry;
+  GtrHistoryEntry *entry = GTR_HISTORY_ENTRY (object);
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
 
   g_return_if_fail (GTR_IS_HISTORY_ENTRY (object));
 
@@ -80,7 +82,7 @@ G_DEFINE_TYPE (GtrHistoryEntry, gtr_history_entry, GTK_TYPE_COMBO_BOX_TEXT)
   switch (prop_id)
     {
     case PROP_HISTORY_ID:
-      entry->priv->history_id = g_value_dup_string (value);
+      priv->history_id = g_value_dup_string (value);
       break;
     case PROP_HISTORY_LENGTH:
       gtr_history_entry_set_history_length (entry, g_value_get_uint (value));
@@ -99,12 +101,11 @@ gtr_history_entry_get_property (GObject * object,
                                 guint prop_id,
                                 GValue * value, GParamSpec * spec)
 {
-  GtrHistoryEntryPrivate *priv;
+  GtrHistoryEntry *entry = GTR_HISTORY_ENTRY (object);
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
 
   g_return_if_fail (GTR_IS_HISTORY_ENTRY (object));
 
-  priv = GTR_HISTORY_ENTRY (object)->priv;
-
   switch (prop_id)
     {
     case PROP_HISTORY_ID:
@@ -126,9 +127,8 @@ gtr_history_entry_get_property (GObject * object,
 static void
 gtr_history_entry_dispose (GObject * object)
 {
-  GtrHistoryEntryPrivate *priv;
-
-  priv = GTR_HISTORY_ENTRY (object)->priv;
+  GtrHistoryEntry *entry = GTR_HISTORY_ENTRY (object);
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
 
   gtr_history_entry_set_enable_completion (GTR_HISTORY_ENTRY (object), FALSE);
 
@@ -140,9 +140,8 @@ gtr_history_entry_dispose (GObject * object)
 static void
 gtr_history_entry_finalize (GObject * object)
 {
-  GtrHistoryEntryPrivate *priv;
-
-  priv = GTR_HISTORY_ENTRY (object)->priv;
+  GtrHistoryEntry *entry = GTR_HISTORY_ENTRY (object);
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
 
   g_free (priv->history_id);
 
@@ -154,9 +153,10 @@ gtr_history_entry_load_history (GtrHistoryEntry * entry)
 {
   gchar **items;
   gsize i;
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
 
-  items = g_settings_get_strv (entry->priv->settings,
-                               entry->priv->history_id);
+  items = g_settings_get_strv (priv->settings,
+                               priv->history_id);
   i = 0;
 
   gtk_combo_box_text_remove_all (GTK_COMBO_BOX_TEXT (entry));
@@ -164,7 +164,7 @@ gtr_history_entry_load_history (GtrHistoryEntry * entry)
   /* Now the default value is an empty string so we have to take care
      of it to not add the empty string in the search list */
   while (items[i] != NULL && *items[i] != '\0' &&
-         i < entry->priv->history_length)
+         i < priv->history_length)
     {
       gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (entry), items[i]);
       i++;
@@ -213,8 +213,6 @@ gtr_history_entry_class_init (GtrHistoryEntryClass * klass)
                                                          TRUE,
                                                          G_PARAM_READWRITE |
                                                          G_PARAM_STATIC_STRINGS));
-
-  g_type_class_add_private (object_class, sizeof (GtrHistoryEntryPrivate));
 }
 
 static GtkListStore *
@@ -267,13 +265,14 @@ static void
 gtr_history_entry_save_history (GtrHistoryEntry * entry)
 {
   gchar **items;
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
 
   g_return_if_fail (GTR_IS_HISTORY_ENTRY (entry));
 
   items = get_history_items (entry);
 
-  g_settings_set_strv (entry->priv->settings,
-                       entry->priv->history_id,
+  g_settings_set_strv (priv->settings,
+                       priv->history_id,
                        (const gchar * const *) items);
 
   g_strfreev (items);
@@ -342,6 +341,7 @@ insert_history_item (GtrHistoryEntry * entry,
                      const gchar * text, gboolean prepend)
 {
   GtkListStore *store;
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
 
   if (g_utf8_strlen (text, -1) <= MIN_ITEM_LEN)
     return;
@@ -354,7 +354,7 @@ insert_history_item (GtrHistoryEntry * entry,
    * would not work */
 
   if (!remove_item (entry, text))
-    clamp_list_store (store, entry->priv->history_length - 1);
+    clamp_list_store (store, priv->history_length - 1);
 
   if (prepend)
     gtk_combo_box_text_prepend_text (GTK_COMBO_BOX_TEXT (entry), text);
@@ -395,10 +395,7 @@ gtr_history_entry_clear (GtrHistoryEntry * entry)
 static void
 gtr_history_entry_init (GtrHistoryEntry * entry)
 {
-  GtrHistoryEntryPrivate *priv;
-
-  priv = GTR_HISTORY_ENTRY_GET_PRIVATE (entry);
-  entry->priv = priv;
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
 
   priv->history_id = NULL;
   priv->history_length = GTR_HISTORY_ENTRY_HISTORY_LENGTH_DEFAULT;
@@ -412,10 +409,11 @@ void
 gtr_history_entry_set_history_length (GtrHistoryEntry * entry,
                                       guint history_length)
 {
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
   g_return_if_fail (GTR_IS_HISTORY_ENTRY (entry));
   g_return_if_fail (history_length > 0);
 
-  entry->priv->history_length = history_length;
+  priv->history_length = history_length;
 
   /* TODO: update if we currently have more items than max */
 }
@@ -423,63 +421,66 @@ gtr_history_entry_set_history_length (GtrHistoryEntry * entry,
 guint
 gtr_history_entry_get_history_length (GtrHistoryEntry * entry)
 {
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
   g_return_val_if_fail (GTR_IS_HISTORY_ENTRY (entry), 0);
 
-  return entry->priv->history_length;
+  return priv->history_length;
 }
 
 void
 gtr_history_entry_set_enable_completion (GtrHistoryEntry * entry,
                                          gboolean enable)
 {
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
   g_return_if_fail (GTR_IS_HISTORY_ENTRY (entry));
 
   if (enable)
     {
-      if (entry->priv->completion != NULL)
+      if (priv->completion != NULL)
         return;
 
-      entry->priv->completion = gtk_entry_completion_new ();
-      gtk_entry_completion_set_model (entry->priv->completion,
+      priv->completion = gtk_entry_completion_new ();
+      gtk_entry_completion_set_model (priv->completion,
                                       GTK_TREE_MODEL (get_history_store
                                                       (entry)));
 
       /* Use model column 0 as the text column */
-      gtk_entry_completion_set_text_column (entry->priv->completion, 0);
+      gtk_entry_completion_set_text_column (priv->completion, 0);
 
-      gtk_entry_completion_set_minimum_key_length (entry->priv->completion,
+      gtk_entry_completion_set_minimum_key_length (priv->completion,
                                                    MIN_ITEM_LEN);
 
-      gtk_entry_completion_set_popup_completion (entry->priv->completion,
+      gtk_entry_completion_set_popup_completion (priv->completion,
                                                  FALSE);
-      gtk_entry_completion_set_inline_completion (entry->priv->completion,
+      gtk_entry_completion_set_inline_completion (priv->completion,
                                                   TRUE);
 
       /* Assign the completion to the entry */
       gtk_entry_set_completion (GTK_ENTRY
                                 (gtr_history_entry_get_entry (entry)),
-                                entry->priv->completion);
+                                priv->completion);
     }
   else
     {
-      if (entry->priv->completion == NULL)
+      if (priv->completion == NULL)
         return;
 
       gtk_entry_set_completion (GTK_ENTRY
                                 (gtr_history_entry_get_entry (entry)), NULL);
 
-      g_object_unref (entry->priv->completion);
+      g_object_unref (priv->completion);
 
-      entry->priv->completion = NULL;
+      priv->completion = NULL;
     }
 }
 
 gboolean
 gtr_history_entry_get_enable_completion (GtrHistoryEntry * entry)
 {
+  GtrHistoryEntryPrivate *priv = gtr_history_entry_get_instance_private (entry);
   g_return_val_if_fail (GTR_IS_HISTORY_ENTRY (entry), FALSE);
 
-  return entry->priv->completion != NULL;
+  return priv->completion != NULL;
 }
 
 GtkWidget *
