@@ -38,21 +38,84 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#define GTR_MESSAGE_TABLE_GET_PRIVATE(object)	(G_TYPE_INSTANCE_GET_PRIVATE (	\
-							(object),		\
-							GTR_TYPE_MESSAGE_TABLE,	\
-							GtrMessageTablePrivate))
+enum
+{
+  PROP_0,
+  PROP_TAB
+};
 
-G_DEFINE_TYPE (GtrMessageTable, gtr_message_table, GTK_TYPE_BOX)
-
-struct _GtrMessageTablePrivate
+typedef struct
 {
   GtkWidget *treeview;
   GtrMessageTableModel *store;
   GtkTreeModel *sort_model;
 
   GtrTab *tab;
-};
+  GtrMessageTableSortBy sort_status;
+} GtrMessageTablePrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (GtrMessageTable, gtr_message_table, GTK_TYPE_BOX)
+
+typedef struct
+{
+  GdkRGBA *fuzzy;
+  GdkRGBA *untranslated;
+  GdkRGBA *translated;
+} GtrMessageColors;
+
+static void
+gtr_message_color_destroy (GtrMessageColors *colors)
+{
+  gdk_rgba_free (colors->fuzzy);
+  gdk_rgba_free (colors->untranslated);
+  gdk_rgba_free (colors->translated);
+  g_free (colors);
+}
+
+static GtrMessageColors *
+gtr_message_color_copy (GtrMessageColors *colors)
+{
+  GtrMessageColors *copy = g_malloc0 (sizeof(GtrMessageColors));
+  copy->fuzzy = gdk_rgba_copy (colors->fuzzy);
+  copy->translated = gdk_rgba_copy (colors->translated);
+  copy->untranslated = gdk_rgba_copy (colors->untranslated);
+
+  return copy;
+}
+
+static void
+colorize_cell (GtkTreeViewColumn *tree_column,
+               GtkCellRenderer *cell,
+               GtkTreeModel *tree_model,
+               GtkTreeIter *iter,
+               gpointer data)
+{
+  GtrMsg *msg;
+  GtrMessageColors *colors = (GtrMessageColors*)data;
+
+  gtk_tree_model_get (tree_model, iter,
+                      GTR_MESSAGE_TABLE_MODEL_POINTER_COLUMN, &msg,
+                      -1);
+
+  if (gtr_msg_is_fuzzy (msg))
+    {
+      g_object_set (cell, "foreground-rgba", colors->fuzzy, NULL);
+      g_object_set (cell, "style", PANGO_STYLE_ITALIC, NULL);
+      g_object_set (cell, "weight", PANGO_WEIGHT_NORMAL, NULL);
+    }
+  else if (gtr_msg_is_translated (msg))
+    {
+      g_object_set (cell, "foreground-rgba", colors->translated, NULL);
+      g_object_set (cell, "style", PANGO_STYLE_NORMAL, NULL);
+      g_object_set (cell, "weight", PANGO_WEIGHT_NORMAL, NULL);
+    }
+  else
+    {
+      g_object_set (cell, "foreground-rgba", colors->untranslated, NULL);
+      g_object_set (cell, "style", PANGO_STYLE_NORMAL, NULL);
+      g_object_set (cell, "weight", PANGO_WEIGHT_BOLD, NULL);
+    }
+}
 
 static void
 showed_message_cb (GtrTab * tab, GtrMsg * msg, GtrMessageTable * table)
@@ -60,19 +123,21 @@ showed_message_cb (GtrTab * tab, GtrMsg * msg, GtrMessageTable * table)
   GtkTreePath *path;
   GtkTreeSelection *selection;
   GtkTreeIter iter, child_iter;
+  GtrMessageTablePrivate *priv;
 
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (table->priv->treeview));
-  gtr_message_table_get_message_iter (table->priv->store, msg, &child_iter);
+  priv = gtr_message_table_get_instance_private (table);
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
+  gtr_message_table_get_message_iter (priv->store, msg, &child_iter);
 
   gtk_tree_model_sort_convert_child_iter_to_iter (GTK_TREE_MODEL_SORT
-                                                  (table->
-                                                   priv->sort_model),
+                                                  (priv->sort_model),
                                                   &iter, &child_iter);
 
   gtk_tree_selection_select_iter (selection, &iter);
-  path = gtk_tree_model_get_path (table->priv->sort_model, &iter);
+  path = gtk_tree_model_get_path (priv->sort_model, &iter);
 
-  gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (table->priv->treeview),
+  gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (priv->treeview),
                                 path, NULL, TRUE, 0.5, 0.0);
 
   gtk_tree_path_free (path);
@@ -85,27 +150,23 @@ gtr_message_table_selection_changed (GtkTreeSelection *selection,
   GtkTreeIter iter;
   GtkTreeModel *model;
   GtrMsg *msg;
-  GList *current_msg = NULL;
-  GtrPo *po;
+  GtrMessageTablePrivate *priv;
 
   g_return_if_fail (selection != NULL);
 
-  po = gtr_tab_get_po (table->priv->tab);
-  current_msg = gtr_po_get_current_message (po);
+  priv = gtr_message_table_get_instance_private (table);
 
   if (gtk_tree_selection_get_selected (selection, &model, &iter) == TRUE)
     {
       gtk_tree_model_get (model, &iter,
                           GTR_MESSAGE_TABLE_MODEL_POINTER_COLUMN, &msg, -1);
 
-      if (msg != NULL
-          && g_utf8_collate (gtr_msg_get_msgid (msg),
-                             gtr_msg_get_msgid (current_msg->data)))
+      if (msg != NULL)
         {
-          g_signal_handlers_block_by_func (table->priv->tab, showed_message_cb, table);
-          gtr_tab_message_go_to (table->priv->tab, msg,
+          g_signal_handlers_block_by_func (priv->tab, showed_message_cb, table);
+          gtr_tab_message_go_to (priv->tab, msg,
                                  FALSE, GTR_TAB_MOVE_NONE);
-          g_signal_handlers_unblock_by_func (table->priv->tab, showed_message_cb, table);
+          g_signal_handlers_unblock_by_func (priv->tab, showed_message_cb, table);
         }
     }
 }
@@ -115,13 +176,16 @@ message_changed_cb (GtrTab * tab, GtrMsg * msg, GtrMessageTable * table)
 {
   GtkTreePath *path;
   GtkTreeIter iter;
+  GtrMessageTablePrivate *priv;
 
-  if (!gtr_message_table_get_message_iter (GTR_MESSAGE_TABLE_MODEL (table->priv->store),
+  priv = gtr_message_table_get_instance_private (table);
+
+  if (!gtr_message_table_get_message_iter (GTR_MESSAGE_TABLE_MODEL (priv->store),
                                            msg, &iter))
     return;
 
-  path = gtk_tree_model_get_path (GTK_TREE_MODEL (table->priv->store), &iter);
-  gtr_message_table_model_update_row (GTR_MESSAGE_TABLE_MODEL (table->priv->store),
+  path = gtk_tree_model_get_path (GTK_TREE_MODEL (priv->store), &iter);
+  gtr_message_table_model_update_row (GTR_MESSAGE_TABLE_MODEL (priv->store),
                                       path);
   gtk_tree_path_free (path);
 }
@@ -156,45 +220,33 @@ model_compare_by_status (GtkTreeModel * model,
 static void
 gtr_message_table_init (GtrMessageTable * table)
 {
-  GtkWidget *scrolledwindow;
   GtkTreeViewColumn *column;
   GtkCellRenderer *renderer;
   GtkTreeSelection *selection;
+  GtrMessageTablePrivate *priv;
 
-  table->priv = GTR_MESSAGE_TABLE_GET_PRIVATE (table);
+  GdkRGBA translated, fuzzy, untranslated;
+  GtkStyleContext *style_context;
+  GtrMessageColors *colors;
+
+  colors = g_malloc0 (sizeof(GtrMessageColors));
+
+  style_context = gtk_widget_get_style_context (GTK_WIDGET (table));
+  gtk_style_context_lookup_color (style_context, "fg_color", &translated);
+  gtk_style_context_lookup_color (style_context, "warning_color", &fuzzy);
+  gtk_style_context_lookup_color (style_context, "error_color", &untranslated);
+
+  colors->fuzzy = gdk_rgba_copy (&fuzzy);
+  colors->translated = gdk_rgba_copy (&translated);
+  colors->untranslated = gdk_rgba_copy (&untranslated);
+
+  priv = gtr_message_table_get_instance_private (table);
+  priv->sort_status = GTR_MESSAGE_TABLE_SORT_ID;
 
   gtk_orientable_set_orientation (GTK_ORIENTABLE (table),
                                   GTK_ORIENTATION_VERTICAL);
 
-  GtrMessageTablePrivate *priv = table->priv;
-
-  priv->treeview = gtk_tree_view_new ();
-
-  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (priv->treeview), TRUE);
-
-  renderer = gtk_cell_renderer_pixbuf_new ();
-  column = gtk_tree_view_column_new_with_attributes (_("Status"),
-                                                     renderer,
-                                                     "icon-name",
-                                                     GTR_MESSAGE_TABLE_MODEL_ICON_COLUMN,
-                                                     NULL);
-
-  gtk_tree_view_column_set_sort_column_id (column,
-                                           GTR_MESSAGE_TABLE_MODEL_STATUS_COLUMN);
-  gtk_tree_view_column_set_resizable (column, FALSE);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (priv->treeview), column);
-
-  renderer = gtk_cell_renderer_text_new ();
-  column = gtk_tree_view_column_new_with_attributes (_("ID"),
-                                                     renderer,
-                                                     "text",
-                                                     GTR_MESSAGE_TABLE_MODEL_ID_COLUMN,
-                                                     NULL);
-
-  gtk_tree_view_column_set_sort_column_id (column,
-                                           GTR_MESSAGE_TABLE_MODEL_ID_COLUMN);
-  gtk_tree_view_column_set_resizable (column, FALSE);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (priv->treeview), column);
+  gtk_widget_init_template (GTK_WIDGET (table));
 
   renderer = gtk_cell_renderer_text_new ();
   g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
@@ -206,6 +258,10 @@ gtr_message_table_init (GtrMessageTable * table)
                                                      GTR_MESSAGE_TABLE_MODEL_ORIGINAL_COLUMN,
                                                      NULL);
 
+  gtk_tree_view_column_set_cell_data_func (column, renderer, colorize_cell,
+                                           colors,
+                                           (GDestroyNotify)gtr_message_color_destroy);
+
   gtk_tree_view_column_set_sort_column_id (column,
                                            GTR_MESSAGE_TABLE_MODEL_ORIGINAL_COLUMN);
   gtk_tree_view_column_set_expand (column, TRUE);
@@ -221,6 +277,10 @@ gtr_message_table_init (GtrMessageTable * table)
                                                      GTR_MESSAGE_TABLE_MODEL_TRANSLATION_COLUMN,
                                                      NULL);
 
+  gtk_tree_view_column_set_cell_data_func (column, renderer, colorize_cell,
+                                           gtr_message_color_copy (colors),
+                                           (GDestroyNotify)gtr_message_color_destroy);
+
   gtk_tree_view_column_set_sort_column_id (column,
                                            GTR_MESSAGE_TABLE_MODEL_TRANSLATION_COLUMN);
   gtk_tree_view_column_set_expand (column, TRUE);
@@ -232,53 +292,101 @@ gtr_message_table_init (GtrMessageTable * table)
 
   g_signal_connect (G_OBJECT (selection), "changed",
                     G_CALLBACK (gtr_message_table_selection_changed), table);
-
-  scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-  gtk_box_pack_start (GTK_BOX (table), scrolledwindow, TRUE, TRUE, 0);
-  gtk_widget_show (scrolledwindow);
-
-  gtk_container_add (GTK_CONTAINER (scrolledwindow), table->priv->treeview);
-  gtk_widget_show (table->priv->treeview);
 }
 
 static void
 gtr_message_table_finalize (GObject * object)
 {
-  DEBUG_PRINT ("Finalize message table");
-
   G_OBJECT_CLASS (gtr_message_table_parent_class)->finalize (object);
 }
 
+static void
+gtr_message_table_set_property (GObject      *object,
+                                guint         prop_id,
+                                const GValue *value,
+                                GParamSpec   *pspec)
+{
+  GtrMessageTable *table = GTR_MESSAGE_TABLE (object);
+  GtrMessageTablePrivate *priv;
+
+  priv = gtr_message_table_get_instance_private (table);
+
+  switch (prop_id)
+    {
+    case PROP_TAB:
+      priv->tab = GTR_TAB (g_value_get_object (value));
+      g_signal_connect (priv->tab,
+                        "showed-message", G_CALLBACK (showed_message_cb), table);
+      g_signal_connect (priv->tab,
+                        "message-changed", G_CALLBACK (message_changed_cb), table);
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+static void
+gtr_message_table_get_property (GObject    *object,
+                                guint       prop_id,
+                                GValue     *value,
+                                GParamSpec *pspec)
+{
+  GtrMessageTable *table = GTR_MESSAGE_TABLE (object);
+  GtrMessageTablePrivate *priv;
+
+  priv = gtr_message_table_get_instance_private (table);
+
+  switch (prop_id)
+    {
+    case PROP_TAB:
+      g_value_set_object (value, priv->tab);
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+
 static void
 gtr_message_table_class_init (GtrMessageTableClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-
-  g_type_class_add_private (klass, sizeof (GtrMessageTablePrivate));
+  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   object_class->finalize = gtr_message_table_finalize;
+  object_class->set_property = gtr_message_table_set_property;
+  object_class->get_property = gtr_message_table_get_property;
+
+  g_object_class_install_property (object_class,
+                                   PROP_TAB,
+                                   g_param_spec_object ("tab",
+                                                        "TAB",
+                                                        "The active tab",
+                                                        GTR_TYPE_TAB,
+                                                        G_PARAM_READWRITE |
+                                                        G_PARAM_CONSTRUCT_ONLY));
+
+  gtk_widget_class_set_template_from_resource (widget_class,
+                                               "/org/gnome/translator/gtr-message-table.ui");
+
+  gtk_widget_class_bind_template_child_private (widget_class, GtrMessageTable, treeview);
 }
 
 /**
  * gtr_message_table_new:
- * @tab: a #GtrTab
  *
  * Creates a new #GtrMessageTable object.
  *
  * Returns: the newly created #GtrMessageTable
  */
 GtkWidget *
-gtr_message_table_new (GtkWidget * tab)
+gtr_message_table_new (void)
 {
-  GtrMessageTable *obj =
-    GTR_MESSAGE_TABLE (g_object_new (GTR_TYPE_MESSAGE_TABLE, NULL));
-  obj->priv->tab = GTR_TAB (tab);
-  g_signal_connect (obj->priv->tab,
-                    "showed-message", G_CALLBACK (showed_message_cb), obj);
-  g_signal_connect (obj->priv->tab,
-                    "message-changed", G_CALLBACK (message_changed_cb), obj);
-
-  return GTK_WIDGET (obj);
+  return GTK_WIDGET (g_object_new (GTR_TYPE_MESSAGE_TABLE, NULL));
 }
 
 /**
@@ -292,35 +400,34 @@ gtr_message_table_new (GtkWidget * tab)
 void
 gtr_message_table_populate (GtrMessageTable * table, GtrMessageContainer * container)
 {
+  GtrMessageTablePrivate *priv;
+
   g_return_if_fail (table != NULL);
   g_return_if_fail (container != NULL);
 
-  if (table->priv->store)
+  priv = gtr_message_table_get_instance_private (table);
+
+  if (priv->store)
     {
-      gtk_tree_view_set_model (GTK_TREE_VIEW (table->priv->treeview), NULL);
-      g_object_unref (table->priv->sort_model);
-      g_object_unref (table->priv->store);
+      gtk_tree_view_set_model (GTK_TREE_VIEW (priv->treeview), NULL);
+      g_object_unref (priv->sort_model);
+      g_object_unref (priv->store);
     }
 
-  table->priv->store = gtr_message_table_model_new (container);
-  table->priv->sort_model =
-    gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (table->priv->store));
-
-  gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
-                                        (table->priv->sort_model),
-                                        GTR_MESSAGE_TABLE_MODEL_ID_COLUMN,
-                                        GTK_SORT_ASCENDING);
+  priv->store = gtr_message_table_model_new (container);
+  priv->sort_model =
+    gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (priv->store));
 
   gtk_tree_sortable_set_default_sort_func (GTK_TREE_SORTABLE
-                                           (table->priv->sort_model),
+                                           (priv->sort_model),
                                            NULL, NULL, NULL);
-
-  gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (table->priv->sort_model),
+  gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (priv->sort_model),
                                    GTR_MESSAGE_TABLE_MODEL_STATUS_COLUMN,
                                    model_compare_by_status, NULL, NULL);
 
-  gtk_tree_view_set_model (GTK_TREE_VIEW (table->priv->treeview),
-                           table->priv->sort_model);
+  gtr_message_table_sort_by (table, priv->sort_status);
+  gtk_tree_view_set_model (GTK_TREE_VIEW (priv->treeview),
+                           priv->sort_model);
 }
 
 /**
@@ -340,10 +447,13 @@ gtr_message_table_navigate (GtrMessageTable * table,
   GtkTreeModel *model;
   GtkTreePath *path;
   GtkTreeIter iter;
+  GtrMessageTablePrivate *priv;
   GtrMsg *msg;
   gboolean cont = TRUE;
 
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (table->priv->treeview));
+  priv = gtr_message_table_get_instance_private (table);
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
 
   if (!gtk_tree_selection_get_selected (selection, &model, &iter))
     return NULL;
@@ -410,7 +520,7 @@ gtr_message_table_navigate (GtrMessageTable * table,
 
   gtk_tree_selection_select_iter (selection, &iter);
   path = gtk_tree_model_get_path (model, &iter);
-  gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (table->priv->treeview),
+  gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (priv->treeview),
                                 path, NULL, TRUE, 0.5, 0.0);
 
   gtk_tree_model_get (model, &iter,
@@ -419,3 +529,58 @@ gtr_message_table_navigate (GtrMessageTable * table,
 
   return msg;
 }
+
+void
+gtr_message_table_sort_by (GtrMessageTable *table,
+                           GtrMessageTableSortBy sort)
+{
+  GtrMessageTablePrivate *priv;
+  priv = gtr_message_table_get_instance_private (table);
+  priv->sort_status = sort;
+
+  switch (sort)
+    {
+    case GTR_MESSAGE_TABLE_SORT_STATUS:
+      gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
+                                            (priv->sort_model),
+                                            GTR_MESSAGE_TABLE_MODEL_STATUS_COLUMN,
+                                            GTK_SORT_ASCENDING);
+      break;
+    case GTR_MESSAGE_TABLE_SORT_STATUS_DESC:
+      gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
+                                            (priv->sort_model),
+                                            GTR_MESSAGE_TABLE_MODEL_STATUS_COLUMN,
+                                            GTK_SORT_DESCENDING);
+      break;
+    case GTR_MESSAGE_TABLE_SORT_MSGID:
+      gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
+                                            (priv->sort_model),
+                                            GTR_MESSAGE_TABLE_MODEL_ORIGINAL_COLUMN,
+                                            GTK_SORT_ASCENDING);
+      break;
+    case GTR_MESSAGE_TABLE_SORT_MSGID_DESC:
+      gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
+                                            (priv->sort_model),
+                                            GTR_MESSAGE_TABLE_MODEL_ORIGINAL_COLUMN,
+                                            GTK_SORT_DESCENDING);
+      break;
+    case GTR_MESSAGE_TABLE_SORT_TRANSLATED:
+      gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
+                                            (priv->sort_model),
+                                            GTR_MESSAGE_TABLE_MODEL_TRANSLATION_COLUMN,
+                                            GTK_SORT_ASCENDING);
+      break;
+    case GTR_MESSAGE_TABLE_SORT_TRANSLATED_DESC:
+      gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
+                                            (priv->sort_model),
+                                            GTR_MESSAGE_TABLE_MODEL_TRANSLATION_COLUMN,
+                                            GTK_SORT_DESCENDING);
+      break;
+    case GTR_MESSAGE_TABLE_SORT_ID:
+    default:
+      gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
+                                            (priv->sort_model),
+                                            GTR_MESSAGE_TABLE_MODEL_ID_COLUMN,
+                                            GTK_SORT_ASCENDING);
+    }
+}
