@@ -42,19 +42,9 @@
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <string.h>
-#include <gtksourceview/gtksourcestyleschememanager.h>
-#include <gdl/gdl.h>
-#include <libpeas-gtk/peas-gtk-plugin-manager.h>
+#include <gtksourceview/gtksource.h>
 
-#define GTR_PREFERENCES_DIALOG_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ( \
-                                                    (object), \
-                                                    GTR_TYPE_PREFERENCES_DIALOG, \
-                                                    GtrPreferencesDialogPrivate))
-
-
-G_DEFINE_TYPE (GtrPreferencesDialog, gtr_preferences_dialog, GTK_TYPE_DIALOG)
-
-struct _GtrPreferencesDialogPrivate
+typedef struct
 {
   GSettings *ui_settings;
   GSettings *editor_settings;
@@ -74,9 +64,6 @@ struct _GtrPreferencesDialogPrivate
   /* Editor->Text display */
   GtkWidget *highlight_syntax_checkbutton;
   GtkWidget *visible_whitespace_checkbutton;
-  GtkWidget *use_custom_font_checkbutton;
-  GtkWidget *editor_font_fontbutton;
-  GtkWidget *editor_font_hbox;
 
   /* Editor->Contents */
   GtkWidget *unmark_fuzzy_when_changed_checkbutton;
@@ -87,10 +74,10 @@ struct _GtrPreferencesDialogPrivate
   GtkWidget *add_button;
   GtkWidget *edit_button;
   GtkWidget *delete_button;
+} GtrPreferencesDialogPrivate;
 
-  /*Plugins */
-  GtkWidget *plugins_box;
-};
+
+G_DEFINE_TYPE_WITH_PRIVATE (GtrPreferencesDialog, gtr_preferences_dialog, GTK_TYPE_DIALOG)
 
 enum
 {
@@ -105,9 +92,10 @@ enum
 static void
 setup_files_general_page (GtrPreferencesDialog * dlg)
 {
-  g_settings_bind (dlg->priv->files_settings,
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
+  g_settings_bind (priv->files_settings,
                    GTR_SETTINGS_WARN_IF_CONTAINS_FUZZY,
-                   dlg->priv->warn_if_contains_fuzzy_checkbutton,
+                   priv->warn_if_contains_fuzzy_checkbutton,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 }
@@ -117,36 +105,38 @@ on_auto_save_changed (GSettings            *settings,
                       const gchar          *key,
                       GtrPreferencesDialog *dlg)
 {
-  gtk_widget_set_sensitive (dlg->priv->autosave_interval_spinbutton,
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
+  gtk_widget_set_sensitive (priv->autosave_interval_spinbutton,
                             g_settings_get_boolean (settings, key));
 }
 
 static void
 setup_files_autosave_page (GtrPreferencesDialog * dlg)
 {
-  g_settings_bind (dlg->priv->files_settings,
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
+  g_settings_bind (priv->files_settings,
                    GTR_SETTINGS_AUTO_SAVE_INTERVAL,
-                   dlg->priv->autosave_interval_spinbutton,
+                   priv->autosave_interval_spinbutton,
                    "value",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 
-  g_settings_bind (dlg->priv->files_settings,
+  g_settings_bind (priv->files_settings,
                    GTR_SETTINGS_AUTO_SAVE,
-                   dlg->priv->autosave_checkbutton,
+                   priv->autosave_checkbutton,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-  g_signal_connect (dlg->priv->files_settings,
+  g_signal_connect (priv->files_settings,
                     "changed::" GTR_SETTINGS_AUTO_SAVE,
                     G_CALLBACK (on_auto_save_changed),
                     dlg);
   /*Set sensitive */
-  on_auto_save_changed (dlg->priv->files_settings,
+  on_auto_save_changed (priv->files_settings,
                         GTR_SETTINGS_AUTO_SAVE,
                         dlg);
 
-  g_settings_bind (dlg->priv->files_settings,
+  g_settings_bind (priv->files_settings,
                    GTR_SETTINGS_CREATE_BACKUP,
-                   dlg->priv->create_backup_checkbutton,
+                   priv->create_backup_checkbutton,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 }
@@ -162,60 +152,34 @@ setup_files_pages (GtrPreferencesDialog * dlg)
 
 /***************Editor pages****************/
 
-static void
-use_custom_font_changed (GSettings            *settings,
-                         const gchar          *key,
-                         GtrPreferencesDialog *dlg)
-{
-  gtk_widget_set_sensitive (dlg->priv->editor_font_hbox,
-                            g_settings_get_boolean (settings, key));
-}
-
 static void
 setup_editor_text_display_page (GtrPreferencesDialog * dlg)
 {
-  g_settings_bind (dlg->priv->editor_settings,
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
+  g_settings_bind (priv->editor_settings,
                    GTR_SETTINGS_HIGHLIGHT_SYNTAX,
-                   dlg->priv->highlight_syntax_checkbutton,
+                   priv->highlight_syntax_checkbutton,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-  g_settings_bind (dlg->priv->editor_settings,
+  g_settings_bind (priv->editor_settings,
                    GTR_SETTINGS_VISIBLE_WHITESPACE,
-                   dlg->priv->visible_whitespace_checkbutton,
+                   priv->visible_whitespace_checkbutton,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-
-  g_settings_bind (dlg->priv->editor_settings,
-                   GTR_SETTINGS_USE_CUSTOM_FONT,
-                   dlg->priv->use_custom_font_checkbutton,
-                   "active",
-                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-  g_signal_connect (dlg->priv->editor_settings,
-                    "changed::" GTR_SETTINGS_USE_CUSTOM_FONT,
-                    G_CALLBACK (use_custom_font_changed), dlg);
-  /*Set sensitive */
-  use_custom_font_changed (dlg->priv->editor_settings,
-                           GTR_SETTINGS_USE_CUSTOM_FONT,
-                           dlg);
-
-  g_settings_bind (dlg->priv->editor_settings,
-                   GTR_SETTINGS_EDITOR_FONT,
-                   dlg->priv->editor_font_fontbutton,
-                   "font-name",
-                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 }
 
 static void
 setup_editor_contents (GtrPreferencesDialog * dlg)
 {
-  g_settings_bind (dlg->priv->editor_settings,
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
+  g_settings_bind (priv->editor_settings,
                    GTR_SETTINGS_UNMARK_FUZZY_WHEN_CHANGED,
-                   dlg->priv->unmark_fuzzy_when_changed_checkbutton,
+                   priv->unmark_fuzzy_when_changed_checkbutton,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-  g_settings_bind (dlg->priv->editor_settings,
+  g_settings_bind (priv->editor_settings,
                    GTR_SETTINGS_SPELLCHECK,
-                   dlg->priv->spellcheck_checkbutton,
+                   priv->spellcheck_checkbutton,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 }
@@ -239,8 +203,9 @@ on_profile_dialog_response_cb (GtrProfileDialog     *profile_dialog,
   GtrProfile *profile;
   GtrProfile *active_profile;
   GtkTreeIter iter;
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
 
-  model = gtk_tree_view_get_model (GTK_TREE_VIEW (dlg->priv->profile_treeview));
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->profile_treeview));
   g_return_if_fail (model != NULL);
 
   prof_manager = gtr_profile_manager_get_default ();
@@ -266,7 +231,7 @@ on_profile_dialog_response_cb (GtrProfileDialog     *profile_dialog,
     {
       GtkTreeSelection *selection;
 
-      selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dlg->priv->profile_treeview));
+      selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->profile_treeview));
 
       if (gtk_tree_selection_get_selected (selection, &model, &iter))
         {
@@ -313,11 +278,12 @@ edit_button_clicked (GtkWidget *button, GtrPreferencesDialog *dlg)
   GtkTreeModel *model;
   GtkTreeSelection *selection;
   GtrProfile *profile;
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
 
-  model = gtk_tree_view_get_model (GTK_TREE_VIEW (dlg->priv->profile_treeview));
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->profile_treeview));
   g_return_if_fail (model != NULL);
 
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dlg->priv->profile_treeview));
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->profile_treeview));
 
   if (gtk_tree_selection_get_selected (selection, &model, &iter))
     {
@@ -339,16 +305,17 @@ static void
 delete_confirm_dialog_cb (GtkWidget *dialog,
                           gint response_id, GtrPreferencesDialog *dlg)
 {
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
   if (response_id == GTK_RESPONSE_YES)
     {
       GtkTreeIter iter;
       GtkTreeModel *model;
       GtkTreeSelection *selection;
 
-      model = gtk_tree_view_get_model (GTK_TREE_VIEW (dlg->priv->profile_treeview));
+      model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->profile_treeview));
       g_return_if_fail (model != NULL);
 
-      selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dlg->priv->profile_treeview));
+      selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->profile_treeview));
 
       if (gtk_tree_selection_get_selected (selection, &model, &iter))
         {
@@ -380,11 +347,13 @@ delete_button_clicked (GtkWidget *button, GtrPreferencesDialog *dlg)
   GtkTreeSelection *selection;
   gboolean active;
   GtkWidget *dialog;
+  gchar *markup;
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
 
-  model = gtk_tree_view_get_model (GTK_TREE_VIEW (dlg->priv->profile_treeview));
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->profile_treeview));
   g_return_if_fail (model != NULL);
 
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dlg->priv->profile_treeview));
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->profile_treeview));
 
   if (gtk_tree_selection_get_selected (selection, &model, &iter))
     {
@@ -397,8 +366,10 @@ delete_button_clicked (GtkWidget *button, GtrPreferencesDialog *dlg)
                                            GTK_MESSAGE_ERROR,
                                            GTK_BUTTONS_CLOSE, NULL);
 
-          gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog),
-                                         _("<span weight=\"bold\" size=\"large\">Impossible to remove the active profile</span>"));
+          markup = g_strdup_printf("<span weight=\"bold\" size=\"large\">%s</span>",
+                                   _("Impossible to remove the active profile"));
+          gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), markup);
+          g_free(markup);
 
           gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG
                                                     (dialog),
@@ -414,14 +385,16 @@ delete_button_clicked (GtkWidget *button, GtrPreferencesDialog *dlg)
                                            GTK_MESSAGE_QUESTION,
                                            GTK_BUTTONS_NONE, NULL);
 
-          gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog),
-                                         _("<span weight=\"bold\" size=\"large\">Are you sure you want to delete this profile?</span>"));
+          markup = g_strdup_printf("<span weight=\"bold\" size=\"large\">%s</span>",
+                                   _("Are you sure you want to delete this profile?"));
+          gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), markup);
+          g_free(markup);
 
           gtk_dialog_add_button (GTK_DIALOG (dialog),
-                                 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+                                 _("_Cancel"), GTK_RESPONSE_CANCEL);
 
           gtk_dialog_add_button (GTK_DIALOG (dialog),
-                                 GTK_STOCK_DELETE, GTK_RESPONSE_YES);
+                                 _("_Delete"), GTK_RESPONSE_YES);
 
           gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -439,10 +412,11 @@ active_toggled_cb (GtkCellRendererToggle *cell_renderer,
   GtkTreePath *path;
   GtkTreeModel *model;
   GtrProfile *active_profile;
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
 
   path = gtk_tree_path_new_from_string (path_str);
 
-  model = gtk_tree_view_get_model (GTK_TREE_VIEW (dlg->priv->profile_treeview));
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->profile_treeview));
   g_return_if_fail (model != NULL);
 
   gtk_tree_model_get_iter (model, &iter, path);
@@ -521,13 +495,14 @@ setup_profile_pages (GtrPreferencesDialog *dlg)
   GtkTreeViewColumn *name_column, *toggle_column;
   GtkCellRenderer *text_renderer, *toggle_renderer;
   GtkListStore *model;
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
 
   model = gtk_list_store_new (PROFILE_N_COLUMNS,
                               G_TYPE_STRING,
                               G_TYPE_BOOLEAN,
                               G_TYPE_POINTER);
 
-  gtk_tree_view_set_model (GTK_TREE_VIEW (dlg->priv->profile_treeview),
+  gtk_tree_view_set_model (GTK_TREE_VIEW (priv->profile_treeview),
                            GTK_TREE_MODEL (model));
 
   g_object_unref (model);
@@ -557,9 +532,9 @@ setup_profile_pages (GtrPreferencesDialog *dlg)
 
   gtk_tree_view_column_set_resizable (toggle_column, TRUE);
   gtk_tree_view_column_set_resizable (name_column, TRUE);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (dlg->priv->profile_treeview),
+  gtk_tree_view_append_column (GTK_TREE_VIEW (priv->profile_treeview),
                                name_column);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (dlg->priv->profile_treeview),
+  gtk_tree_view_append_column (GTK_TREE_VIEW (priv->profile_treeview),
                                toggle_column);
 
   gtk_tree_view_column_set_expand (name_column, TRUE);
@@ -567,38 +542,16 @@ setup_profile_pages (GtrPreferencesDialog *dlg)
   fill_profile_treeview (dlg, GTK_TREE_MODEL (model));
 
   /* Connect the signals */
-  g_signal_connect (dlg->priv->add_button,
+  g_signal_connect (priv->add_button,
                     "clicked", G_CALLBACK (add_button_clicked), dlg);
 
-  g_signal_connect (dlg->priv->delete_button,
+  g_signal_connect (priv->delete_button,
                     "clicked", G_CALLBACK (delete_button_clicked), dlg);
 
-  g_signal_connect (dlg->priv->edit_button,
+  g_signal_connect (priv->edit_button,
                     "clicked", G_CALLBACK (edit_button_clicked), dlg);
 }
 
-/***************Plugins pages****************/
-static void
-setup_plugin_pages (GtrPreferencesDialog * dlg)
-{
-  GtkWidget *alignment;
-  GtkWidget *page_content;
-
-  alignment = gtk_alignment_new (0., 0., 1., 1.);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 12, 12, 12, 12);
-
-  page_content = peas_gtk_plugin_manager_new (NULL);
-  g_return_if_fail (page_content != NULL);
-
-  gtk_container_add (GTK_CONTAINER (alignment), page_content);
-
-  gtk_box_pack_start (GTK_BOX (dlg->priv->plugins_box),
-                      alignment, TRUE, TRUE, 0);
-
-  gtk_widget_show_all (page_content);
-}
-
-
 static void
 dialog_response_handler (GtkDialog * dlg, gint res_id)
 {
@@ -612,8 +565,6 @@ dialog_response_handler (GtkDialog * dlg, gint res_id)
 static void
 gtr_preferences_dialog_init (GtrPreferencesDialog * dlg)
 {
-  GtrPreferencesDialogPrivate *priv;
-  GtkWidget *action_area;
   GtkWidget *profiles_toolbar;
   GtkWidget *profiles_scrolled_window;
   GtkBuilder *builder;
@@ -627,37 +578,31 @@ gtr_preferences_dialog_init (GtrPreferencesDialog * dlg)
     "model1",
     NULL
   };
-
-  dlg->priv = GTR_PREFERENCES_DIALOG_GET_PRIVATE (dlg);
-  priv = dlg->priv;
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
 
   priv->ui_settings = g_settings_new ("org.gnome.gtranslator.preferences.ui");
   priv->editor_settings = g_settings_new ("org.gnome.gtranslator.preferences.editor");
   priv->files_settings = g_settings_new ("org.gnome.gtranslator.preferences.files");
 
   gtk_dialog_add_buttons (GTK_DIALOG (dlg),
-                          GTK_STOCK_CLOSE,
-                          GTK_RESPONSE_CLOSE,
-                          GTK_STOCK_HELP, GTK_RESPONSE_HELP, NULL);
+                          _("_Close"), GTK_RESPONSE_CLOSE,
+                          _("Help"), GTK_RESPONSE_HELP, NULL);
 
-  gtk_window_set_title (GTK_WINDOW (dlg), _("Gtranslator Preferences"));
+  gtk_window_set_title (GTK_WINDOW (dlg), _("Translation Editor Preferences"));
   gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
 
-  action_area = gtk_dialog_get_action_area (GTK_DIALOG (dlg));
   content_area = GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg)));
 
   /* HIG defaults */
   gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);
   gtk_box_set_spacing (content_area, 2);    /* 2 * 5 + 2 = 12 */
-  gtk_container_set_border_width (GTK_CONTAINER (action_area), 5);
-  gtk_box_set_spacing (GTK_BOX (action_area), 4);
 
   g_signal_connect (dlg,
                     "response", G_CALLBACK (dialog_response_handler), NULL);
 
   builder = gtk_builder_new ();
-  gtk_builder_add_objects_from_resource (builder, "/org/gnome/gtranslator/ui/gtr-preferences-dialog.ui",
+  gtk_builder_add_objects_from_resource (builder, "/org/gnome/translator/gtr-preferences-dialog.ui",
                                          root_objects, NULL);
   priv->notebook = GTK_WIDGET (gtk_builder_get_object (builder, "notebook"));
   g_object_ref (priv->notebook);
@@ -668,9 +613,6 @@ gtr_preferences_dialog_init (GtrPreferencesDialog * dlg)
   priv->create_backup_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "create_backup_checkbutton"));
   priv->highlight_syntax_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "highlight_checkbutton"));
   priv->visible_whitespace_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "visible_whitespace_checkbutton"));
-  priv->use_custom_font_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "use_custom_font_checkbutton"));
-  priv->editor_font_fontbutton = GTK_WIDGET (gtk_builder_get_object (builder, "editor_font_fontbutton"));
-  priv->editor_font_hbox = GTK_WIDGET (gtk_builder_get_object (builder, "editor_font_hbox"));
   priv->unmark_fuzzy_when_changed_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "unmark_fuzzy_checkbutton"));
   priv->spellcheck_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "spellcheck_checkbutton"));
   priv->profile_treeview = GTK_WIDGET (gtk_builder_get_object (builder, "profile_treeview"));
@@ -679,7 +621,6 @@ gtr_preferences_dialog_init (GtrPreferencesDialog * dlg)
   priv->delete_button = GTK_WIDGET (gtk_builder_get_object (builder, "delete-button"));
   profiles_toolbar = GTK_WIDGET (gtk_builder_get_object (builder, "profiles-toolbar"));
   profiles_scrolled_window = GTK_WIDGET (gtk_builder_get_object (builder, "profiles-scrolledwindow"));
-  priv->plugins_box = GTK_WIDGET (gtk_builder_get_object (builder, "plugins_box"));
   g_object_unref (builder);
 
   gtk_box_pack_start (content_area, priv->notebook, FALSE, FALSE, 0);
@@ -695,17 +636,17 @@ gtr_preferences_dialog_init (GtrPreferencesDialog * dlg)
   setup_files_pages (dlg);
   setup_editor_pages (dlg);
   setup_profile_pages (dlg);
-  setup_plugin_pages (dlg);
 }
 
 static void
 gtr_preferences_dialog_dispose (GObject * object)
 {
   GtrPreferencesDialog *dlg = GTR_PREFERENCES_DIALOG (object);
+  GtrPreferencesDialogPrivate *priv = gtr_preferences_dialog_get_instance_private (dlg);
 
-  g_clear_object (&dlg->priv->ui_settings);
-  g_clear_object (&dlg->priv->editor_settings);
-  g_clear_object (&dlg->priv->files_settings);
+  g_clear_object (&priv->ui_settings);
+  g_clear_object (&priv->editor_settings);
+  g_clear_object (&priv->files_settings);
 
   G_OBJECT_CLASS (gtr_preferences_dialog_parent_class)->dispose (object);
 }
@@ -715,8 +656,6 @@ gtr_preferences_dialog_class_init (GtrPreferencesDialogClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GtrPreferencesDialogPrivate));
-
   object_class->dispose = gtr_preferences_dialog_dispose;
 }
 
@@ -729,16 +668,16 @@ gtr_show_preferences_dialog (GtrWindow * window)
 
   if (dlg == NULL)
     {
-      dlg = GTK_WIDGET (g_object_new (GTR_TYPE_PREFERENCES_DIALOG, NULL));
+      dlg = GTK_WIDGET (g_object_new (GTR_TYPE_PREFERENCES_DIALOG,
+                                      "use-header-bar", TRUE, NULL));
       g_signal_connect (dlg,
                         "destroy", G_CALLBACK (gtk_widget_destroyed), &dlg);
       gtk_widget_show_all (dlg);
     }
 
-  if (GTK_WINDOW (window) != gtk_window_get_transient_for (GTK_WINDOW (dlg)))
-    {
-      gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (window));
-    }
+  gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (window));
+  gtk_window_set_type_hint (GTK_WINDOW (dlg), GDK_WINDOW_TYPE_HINT_DIALOG);
+  gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
 
   gtk_window_present (GTK_WINDOW (dlg));
 }
