@@ -22,7 +22,6 @@
  */
 
 #include <string.h>
-#include <gdl/gdl.h>
 #include <gtksourceview/gtksource.h>
 
 #include "gtr-settings.h"
@@ -33,11 +32,7 @@
 #include "gtr-dirs.h"
 #include "gtr-utils.h"
 
-#define GTR_SETTINGS_SYSTEM_FONT "monospace-font-name"
-
-#define GTR_SETTINGS_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GTR_TYPE_SETTINGS, GtrSettingsPrivate))
-
-struct _GtrSettingsPrivate
+typedef struct
 {
   GSettings *interface;
   GSettings *editor;
@@ -45,16 +40,17 @@ struct _GtrSettingsPrivate
   GSettings *files;
 
   gchar *old_scheme;
-};
+} GtrSettingsPrivate;
 
-G_DEFINE_TYPE (GtrSettings, gtr_settings, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (GtrSettings, gtr_settings, G_TYPE_OBJECT)
 
 static void
 gtr_settings_finalize (GObject * object)
 {
   GtrSettings *gs = GTR_SETTINGS (object);
+  GtrSettingsPrivate *priv = gtr_settings_get_instance_private (gs);
 
-  g_free (gs->priv->old_scheme);
+  g_free (priv->old_scheme);
 
   G_OBJECT_CLASS (gtr_settings_parent_class)->finalize (object);
 }
@@ -63,94 +59,15 @@ static void
 gtr_settings_dispose (GObject * object)
 {
   GtrSettings *gs = GTR_SETTINGS (object);
+  GtrSettingsPrivate *priv = gtr_settings_get_instance_private (gs);
 
-  g_clear_object (&gs->priv->interface);
-  g_clear_object (&gs->priv->editor);
-  g_clear_object (&gs->priv->ui);
+  g_clear_object (&priv->interface);
+  g_clear_object (&priv->editor);
+  g_clear_object (&priv->ui);
 
   G_OBJECT_CLASS (gtr_settings_parent_class)->dispose (object);
 }
 
-static void
-set_font (GtrSettings * gs, const gchar * font)
-{
-  GList *views, *l;
-
-  views = gtr_application_get_views (GTR_APP, TRUE, TRUE);
-
-  for (l = views; l != NULL; l = g_list_next (l))
-    {
-      /* Note: we use def=FALSE to avoid GtrView to query gconf */
-      gtr_view_set_font (GTR_VIEW (l->data), FALSE, font);
-    }
-
-  g_list_free (views);
-}
-
-static void
-on_system_font_changed (GSettings * settings,
-                        const gchar * key, GtrSettings * gs)
-{
-
-  gboolean use_custom_font;
-  gchar *font;
-
-  use_custom_font = g_settings_get_boolean (gs->priv->editor,
-                                            GTR_SETTINGS_USE_CUSTOM_FONT);
-  if (!use_custom_font)
-    return;
-
-  font = g_settings_get_string (settings, key);
-
-  set_font (gs, font);
-
-  g_free (font);
-}
-
-static void
-on_use_custom_font_changed (GSettings * settings,
-                            const gchar * key, GtrSettings * gs)
-{
-  gboolean def;
-  gchar *font;
-
-  def = g_settings_get_boolean (settings, key);
-
-  if (!def)
-    {
-      font = g_settings_get_string (gs->priv->interface,
-                                    GTR_SETTINGS_SYSTEM_FONT);
-    }
-  else
-    {
-      font = g_settings_get_string (gs->priv->editor,
-                                    GTR_SETTINGS_EDITOR_FONT);
-    }
-
-  set_font (gs, font);
-
-  g_free (font);
-}
-
-static void
-on_editor_font_changed (GSettings * settings,
-                        const gchar * key, GtrSettings * gs)
-{
-  gboolean use_custom_font;
-  gchar *font;
-
-  use_custom_font = g_settings_get_boolean (gs->priv->editor,
-                                            GTR_SETTINGS_USE_CUSTOM_FONT);
-  if (!use_custom_font)
-    return;
-
-  font = g_settings_get_string (settings, key);
-
-  set_font (gs, font);
-
-  g_free (font);
-}
-
 static void
 on_auto_save_changed (GSettings * settings,
                       const gchar * key, GtrSettings * gs)
@@ -281,44 +198,34 @@ on_scheme_changed (GSettings * settings, const gchar * key, GtrSettings * gs)
 static void
 gtr_settings_init (GtrSettings * gs)
 {
-  gs->priv = GTR_SETTINGS_GET_PRIVATE (gs);
+  GtrSettingsPrivate *priv = gtr_settings_get_instance_private (gs);
 
-  gs->priv->old_scheme = NULL;
+  priv->old_scheme = NULL;
 
-  gs->priv->files = g_settings_new ("org.gnome.gtranslator.preferences.files");
-  gs->priv->editor = g_settings_new ("org.gnome.gtranslator.preferences.editor");
-  gs->priv->ui = g_settings_new ("org.gnome.gtranslator.preferences.ui");
+  priv->files = g_settings_new ("org.gnome.gtranslator.preferences.files");
+  priv->editor = g_settings_new ("org.gnome.gtranslator.preferences.editor");
+  priv->ui = g_settings_new ("org.gnome.gtranslator.preferences.ui");
 
   /* Load settings */
-  gs->priv->interface = g_settings_new ("org.gnome.desktop.interface");
-
-  g_signal_connect (gs->priv->interface,
-                    "changed::monospace-font-name",
-                    G_CALLBACK (on_system_font_changed), gs);
+  priv->interface = g_settings_new ("org.gnome.desktop.interface");
 
   /* editor changes */
-  g_signal_connect (gs->priv->files,
+  g_signal_connect (priv->files,
                     "changed::autosave",
                     G_CALLBACK (on_auto_save_changed), gs);
-  g_signal_connect (gs->priv->files,
+  g_signal_connect (priv->files,
                     "changed::autosave-interval",
                     G_CALLBACK (on_auto_save_interval_changed), gs);
-  g_signal_connect (gs->priv->editor,
-                    "changed::use-custom-font",
-                    G_CALLBACK (on_use_custom_font_changed), gs);
-  g_signal_connect (gs->priv->editor,
-                    "changed::editor-font",
-                    G_CALLBACK (on_editor_font_changed), gs);
-  g_signal_connect (gs->priv->editor,
+  g_signal_connect (priv->editor,
                     "changed::highlight-syntax",
                     G_CALLBACK (on_syntax_highlighting_changed), gs);
-  g_signal_connect (gs->priv->editor,
+  g_signal_connect (priv->editor,
                     "changed::visible-whitespace",
                     G_CALLBACK (on_visible_whitespace_changed), gs);
-  g_signal_connect (gs->priv->editor,
+  g_signal_connect (priv->editor,
                     "changed::spellcheck",
                     G_CALLBACK (on_spellcheck_changed), gs);
-  g_signal_connect (gs->priv->ui,
+  g_signal_connect (priv->ui,
                     "changed::color-scheme",
                     G_CALLBACK (on_scheme_changed), gs);
 }
@@ -330,8 +237,6 @@ gtr_settings_class_init (GtrSettingsClass * klass)
 
   object_class->finalize = gtr_settings_finalize;
   object_class->dispose = gtr_settings_dispose;
-
-  g_type_class_add_private (object_class, sizeof (GtrSettingsPrivate));
 }
 
 GSettings *
@@ -340,17 +245,4 @@ gtr_settings_new ()
   return g_object_new (GTR_TYPE_SETTINGS, NULL);
 }
 
-gchar *
-gtr_settings_get_system_font (GtrSettings * gs)
-{
-  gchar *system_font;
-
-  g_return_val_if_fail (GTR_IS_SETTINGS (gs), NULL);
-
-  system_font = g_settings_get_string (gs->priv->interface,
-                                       "monospace-font-name");
-
-  return system_font;
-}
-
 /* ex:ts=8:noet: */
