@@ -39,22 +39,48 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include <gtksourceview/gtksourcelanguagemanager.h>
-#include <gtksourceview/gtksourcebuffer.h>
-#include <gtksourceview/gtksourcestyleschememanager.h>
+#include <gtksourceview/gtksource.h>
 
-#ifdef HAVE_GTKSPELL
-#include <gtkspell/gtkspell.h>
-#endif
+#include <gspell/gspell.h>
 
-#define GTR_VIEW_GET_PRIVATE(object)	(G_TYPE_INSTANCE_GET_PRIVATE ( \
-						 	(object),	\
-						 	GTR_TYPE_VIEW,     \
-						 	GtrViewPrivate))
+/**
+ * Converts the language code to a complete language code with the country
+ * If the language contains the country code this returns a new allocated
+ * string copied from *lang*.
+ *
+ * In other case the code is duplicated by default:
+ *
+ * es -> es_ES
+ * pt -> pt_PT
+ */
+static gchar*
+get_default_lang (const gchar *lang) {
+  gchar *up;
+  gchar *ret;
 
-G_DEFINE_TYPE (GtrView, gtr_view, GTK_SOURCE_TYPE_VIEW)
+  if (g_strrstr (lang, "_"))
+    {
+      return g_strdup (lang);
+    }
 
-struct _GtrViewPrivate
+  up = g_ascii_strup (lang, -1);
+  ret = g_strdup_printf ("%s_%s", lang, up);
+  g_free (up);
+
+  return ret;
+}
+
+static void
+inline_spellcheck (GObject *object,
+                   GParamSpec *param,
+                   GtrView *view)
+{
+  GspellTextView *gspell_view;
+  gspell_view = gspell_text_view_get_from_gtk_text_view (GTK_TEXT_VIEW (view));
+  gspell_text_view_set_inline_spell_checking (gspell_view, TRUE);
+}
+
+typedef struct
 {
   GSettings *editor_settings;
   GSettings *ui_settings;
@@ -64,38 +90,10 @@ struct _GtrViewPrivate
   guint search_flags;
   gchar *search_text;
 
-#ifdef HAVE_GTKSPELL
-  GtkSpellChecker *spell;
-#endif
-};
+  GspellChecker *spell;
+} GtrViewPrivate;
 
-#ifdef HAVE_GTKSPELL
-static void
-gtr_attach_gtkspell (GtrView * view)
-{
-  GError *error = NULL;
-  gchar *errortext = NULL;
-
-  view->priv->spell = gtk_spell_checker_new ();
-  gtk_spell_checker_set_language (view->priv->spell, NULL, &error);
-  if (error)
-    {
-      g_warning (_("gtkspell error: %s\n"), error->message);
-      errortext =
-        g_strdup_printf (_("GtkSpell was unable to initialize.\n %s"),
-                         error->message);
-      g_warning ("%s", errortext);
-
-      g_error_free (error);
-      g_free (errortext);
-    }
-  else
-    {
-      gtk_spell_checker_attach (view->priv->spell,
-                                GTK_TEXT_VIEW (view));
-    }
-}
-#endif
+G_DEFINE_TYPE_WITH_PRIVATE (GtrView, gtr_view, GTK_SOURCE_TYPE_VIEW)
 
 static void
 gtr_view_init (GtrView * view)
@@ -108,10 +106,9 @@ gtr_view_init (GtrView * view)
   gchar *ui_dir;
   GtrViewPrivate *priv;
 
-  view->priv = GTR_VIEW_GET_PRIVATE (view);
-
-  priv = view->priv;
+  priv = gtr_view_get_instance_private (view);
 
+  priv->spell = NULL;
   priv->editor_settings = g_settings_new ("org.gnome.gtranslator.preferences.editor");
   priv->ui_settings = g_settings_new ("org.gnome.gtranslator.preferences.ui");
 
@@ -147,36 +144,22 @@ gtr_view_init (GtrView * view)
                                       g_settings_get_boolean (priv->editor_settings,
                                                               GTR_SETTINGS_VISIBLE_WHITESPACE));
 
-  /* Set fonts according to preferences */
-  if (g_settings_get_boolean (priv->editor_settings, GTR_SETTINGS_USE_CUSTOM_FONT))
-    {
-      gchar *editor_font;
-
-      editor_font = g_settings_get_string (priv->editor_settings,
-                                           GTR_SETTINGS_EDITOR_FONT);
-
-      gtr_view_set_font (view, FALSE, editor_font);
-
-      g_free (editor_font);
-    }
-  else
-    {
-      gtr_view_set_font (view, TRUE, NULL);
-    }
-
   /* Set scheme color according to preferences */
   gtr_view_reload_scheme_color (view);
+  gtk_text_view_set_monospace (GTK_TEXT_VIEW (view), TRUE);
 }
 
 static void
 gtr_view_dispose (GObject * object)
 {
   GtrView *view = GTR_VIEW (object);
+  GtrViewPrivate *priv;
 
-  DEBUG_PRINT ("Dispose view");
+  priv = gtr_view_get_instance_private (view);
 
-  g_clear_object (&view->priv->editor_settings);
-  g_clear_object (&view->priv->ui_settings);
+  g_clear_object (&priv->editor_settings);
+  g_clear_object (&priv->ui_settings);
+  g_clear_object (&priv->spell);
 
   G_OBJECT_CLASS (gtr_view_parent_class)->dispose (object);
 }
@@ -186,8 +169,6 @@ gtr_view_class_init (GtrViewClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GtrViewPrivate));
-
   object_class->dispose = gtr_view_dispose;
 }
 
@@ -246,6 +227,67 @@ gtr_view_get_selected_text (GtrView * view,
   return TRUE;
 }
 
+void
+gtr_view_set_language (GtrView *view,
+                       const gchar *lang)
+{
+  GtrViewPrivate *priv = gtr_view_get_instance_private (view);
+  GList *langs = (GList *)gspell_language_get_available ();
+  gchar **lang_parts = NULL;
+  gboolean found = FALSE;
+  gchar *def_lang = get_default_lang (lang);
+
+  while (langs)
+    {
+      GspellLanguage *l = (GspellLanguage*) langs->data;
+      const gchar *code = gspell_language_get_code (l);
+      if (g_strcmp0 (def_lang, code) == 0)
+        {
+          gspell_checker_set_language (priv->spell, l);
+          // If we found the language exacly, we're finished
+          found = TRUE;
+          break;
+        }
+
+      langs = g_list_next (langs);
+    }
+
+  g_free (def_lang);
+
+  if (found)
+    return;
+
+  // Not found, trying again, but this time only with the first part of
+  // the language code
+
+  langs = (GList *)gspell_language_get_available ();
+  lang_parts = g_strsplit (lang, "_", 2);
+  while (langs)
+    {
+      GspellLanguage *l = (GspellLanguage*) langs->data;
+      const gchar *code = gspell_language_get_code (l);
+      gchar **parts = g_strsplit (code, "_", 2);
+      if (parts[0] && g_strcmp0 (parts[0], lang_parts[0]) == 0)
+        {
+          gspell_checker_set_language (priv->spell, l);
+          g_strfreev (parts);
+          found = TRUE;
+          break;
+        }
+      g_strfreev (parts);
+
+      langs = g_list_next (langs);
+    }
+  g_strfreev (lang_parts);
+
+  if (!found)
+    {
+      GspellTextView *gspell_view;
+      gspell_view = gspell_text_view_get_from_gtk_text_view (GTK_TEXT_VIEW (view));
+      gspell_text_view_set_inline_spell_checking (gspell_view, FALSE);
+    }
+}
+
 /**
  * gtr_view_enable_spellcheck:
  * @view: a #GtrView
@@ -256,20 +298,24 @@ gtr_view_get_selected_text (GtrView * view,
 void
 gtr_view_enable_spellcheck (GtrView * view, gboolean enable)
 {
-  if (enable)
-    {
-#ifdef HAVE_GTKSPELL
-      gtr_attach_gtkspell (view);
-#endif
-    }
-  else
-    {
-#ifdef HAVE_GTKSPELL
-      if (!view->priv->spell)
-        return;
-      gtk_spell_checker_detach (view->priv->spell);
-#endif
-    }
+  GtrViewPrivate *priv;
+  GspellTextView *gspell_view;
+  GtkTextBuffer *gtk_buffer;
+  GspellTextBuffer *gspell_buffer;
+
+  priv = gtr_view_get_instance_private (view);
+
+  priv->spell = gspell_checker_new (NULL);
+  gtk_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+  gspell_buffer = gspell_text_buffer_get_from_gtk_text_buffer (gtk_buffer);
+  gspell_text_buffer_set_spell_checker (gspell_buffer, priv->spell);
+
+  gspell_view = gspell_text_view_get_from_gtk_text_view (GTK_TEXT_VIEW (view));
+  gspell_text_view_set_inline_spell_checking (gspell_view, enable);
+  gspell_text_view_set_enable_language_menu (gspell_view, TRUE);
+
+  g_signal_connect (G_OBJECT (priv->spell), "notify::language",
+                    G_CALLBACK (inline_spellcheck), view);
 }
 
 /**
@@ -282,13 +328,23 @@ gtr_view_enable_spellcheck (GtrView * view, gboolean enable)
 void
 gtr_view_enable_visible_whitespace (GtrView * view, gboolean enable)
 {
+  GtkSourceView *source;
+  GtkSourceSpaceDrawer *drawer;
+
   g_return_if_fail (GTR_IS_VIEW (view));
 
+  source = GTK_SOURCE_VIEW (view);
+  drawer = gtk_source_view_get_space_drawer (source);
+  gtk_source_space_drawer_set_enable_matrix (drawer, TRUE);
+
   if (enable)
-    gtk_source_view_set_draw_spaces (GTK_SOURCE_VIEW (view),
-                                     GTK_SOURCE_DRAW_SPACES_ALL);
+    gtk_source_space_drawer_set_types_for_locations (drawer,
+                                                     GTK_SOURCE_SPACE_LOCATION_ALL,
+                                                     GTK_SOURCE_SPACE_TYPE_ALL);
   else
-    gtk_source_view_set_draw_spaces (GTK_SOURCE_VIEW (view), 0);
+    gtk_source_space_drawer_set_types_for_locations (drawer,
+                                                     GTK_SOURCE_SPACE_LOCATION_NONE,
+                                                     GTK_SOURCE_SPACE_TYPE_NONE);
 }
 
 /**
@@ -381,44 +437,6 @@ gtr_view_paste_clipboard (GtrView * view)
                                 0.0, FALSE, 0.0, 0.0);
 }
 
-/**
- * gtr_view_set_font:
- * @view: a #GtrView
- * @def: TRUE if you want to use the default font
- * @font_name: The name of the font you want to use in the #GtrView
- * 
- * Sets the #GtrView font.
- **/
-void
-gtr_view_set_font (GtrView * view, gboolean def, const gchar * font_name)
-{
-  PangoFontDescription *font_desc = NULL;
-
-  g_return_if_fail (GTR_IS_VIEW (view));
-
-  if (def)
-    {
-      GSettings *gtr_settings;
-      gchar *font;
-
-      gtr_settings = _gtr_application_get_settings (GTR_APP);
-      font = gtr_settings_get_system_font (GTR_SETTINGS (gtr_settings));
-
-      font_desc = pango_font_description_from_string (font);
-      g_free (font);
-    }
-  else
-    {
-      font_desc = pango_font_description_from_string (font_name);
-    }
-
-  g_return_if_fail (font_desc != NULL);
-
-  gtk_widget_modify_font (GTK_WIDGET (view), font_desc);
-
-  pango_font_description_free (font_desc);
-}
-
 
 /**
  * gtr_view_set_search_text:
@@ -431,10 +449,13 @@ gtr_view_set_font (GtrView * view, gboolean def, const gchar * font_name)
 void
 gtr_view_set_search_text (GtrView * view, const gchar * text, guint flags)
 {
+  GtrViewPrivate *priv;
   gchar *converted_text;
 
   g_return_if_fail (GTR_IS_VIEW (view));
-  g_return_if_fail ((text == NULL) || (view->priv->search_text != text));
+
+  priv = gtr_view_get_instance_private (view);
+  g_return_if_fail ((text == NULL) || (priv->search_text != text));
   g_return_if_fail ((text == NULL) || g_utf8_validate (text, -1, NULL));
 
   //gedit_debug_message (DEBUG_DOCUMENT, "text = %s", text);
@@ -450,19 +471,19 @@ gtr_view_set_search_text (GtrView * view, const gchar * text, guint flags)
           converted_text = g_strdup ("");
         }
 
-      g_free (view->priv->search_text);
+      g_free (priv->search_text);
 
-      view->priv->search_text = converted_text;
-      //view->priv->num_of_lines_search_text = compute_num_of_lines (view->priv->search_text);
+      priv->search_text = converted_text;
+      //priv->num_of_lines_search_text = compute_num_of_lines (priv->search_text);
       //update_to_search_region = TRUE;
     }
 
   if (!GTR_SEARCH_IS_DONT_SET_FLAGS (flags))
     {
-      /*if (view->priv->search_flags != flags)
+      /*if (priv->search_flags != flags)
          update_to_search_region = TRUE; */
 
-      view->priv->search_flags = flags;
+      priv->search_flags = flags;
 
     }
 
@@ -494,12 +515,16 @@ gtr_view_set_search_text (GtrView * view, const gchar * text, guint flags)
 gchar *
 gtr_view_get_search_text (GtrView * view, guint * flags)
 {
+  GtrViewPrivate *priv;
+
   g_return_val_if_fail (GTR_IS_VIEW (view), NULL);
 
-  if (flags != NULL)
-    *flags = view->priv->search_flags;
+  priv = gtr_view_get_instance_private (view);
 
-  return gtr_utils_escape_search_text (view->priv->search_text);
+  if (flags != NULL)
+    *flags = priv->search_flags;
+
+  return gtr_utils_escape_search_text (priv->search_text);
 }
 
 /**
@@ -511,10 +536,13 @@ gtr_view_get_search_text (GtrView * view, guint * flags)
 gboolean
 gtr_view_get_can_search_again (GtrView * view)
 {
+  GtrViewPrivate *priv;
+
   g_return_val_if_fail (GTR_IS_VIEW (view), FALSE);
 
-  return ((view->priv->search_text != NULL) &&
-          (*view->priv->search_text != '\0'));
+  priv = gtr_view_get_instance_private (view);
+  return ((priv->search_text != NULL) &&
+          (*priv->search_text != '\0'));
 }
 
 /**
@@ -545,6 +573,7 @@ gtr_view_search_forward (GtrView * view,
   gboolean found = FALSE;
   GtkTextIter m_start;
   GtkTextIter m_end;
+  GtrViewPrivate *priv;
 
   g_return_val_if_fail (GTR_IS_VIEW (view), FALSE);
 
@@ -557,7 +586,9 @@ gtr_view_search_forward (GtrView * view,
                         || (gtk_text_iter_get_buffer (end) ==
                             GTK_TEXT_BUFFER (doc)), FALSE);
 
-  if (view->priv->search_text == NULL)
+  priv = gtr_view_get_instance_private (view);
+
+  if (priv->search_text == NULL)
     {
       //gedit_debug_message (DEBUG_DOCUMENT, "doc->priv->search_text == NULL\n");
       return FALSE;
@@ -572,7 +603,7 @@ gtr_view_search_forward (GtrView * view,
 
   search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
-  if (!GTR_SEARCH_IS_CASE_SENSITIVE (view->priv->search_flags))
+  if (!GTR_SEARCH_IS_CASE_SENSITIVE (priv->search_flags))
     {
       search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
     }
@@ -580,11 +611,11 @@ gtr_view_search_forward (GtrView * view,
   while (!found)
     {
       found = gtk_text_iter_forward_search (&iter,
-                                            view->priv->search_text,
+                                            priv->search_text,
                                             search_flags,
                                             &m_start, &m_end, end);
 
-      if (found && GTR_SEARCH_IS_ENTIRE_WORD (view->priv->search_flags))
+      if (found && GTR_SEARCH_IS_ENTIRE_WORD (priv->search_flags))
         {
           found = gtk_text_iter_starts_word (&m_start) &&
             gtk_text_iter_ends_word (&m_end);
@@ -633,6 +664,7 @@ gtr_view_search_backward (GtrView * view,
   gboolean found = FALSE;
   GtkTextIter m_start;
   GtkTextIter m_end;
+  GtrViewPrivate *priv;
 
   g_return_val_if_fail (GTR_IS_VIEW (view), FALSE);
 
@@ -645,7 +677,9 @@ gtr_view_search_backward (GtrView * view,
                         || (gtk_text_iter_get_buffer (end) ==
                             GTK_TEXT_BUFFER (doc)), FALSE);
 
-  if (view->priv->search_text == NULL)
+  priv = gtr_view_get_instance_private (view);
+
+  if (priv->search_text == NULL)
     {
       //gedit_debug_message (DEBUG_DOCUMENT, "doc->priv->search_text == NULL\n");
       return FALSE;
@@ -660,7 +694,7 @@ gtr_view_search_backward (GtrView * view,
 
   search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
-  if (!GTR_SEARCH_IS_CASE_SENSITIVE (view->priv->search_flags))
+  if (!GTR_SEARCH_IS_CASE_SENSITIVE (priv->search_flags))
     {
       search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
     }
@@ -668,11 +702,11 @@ gtr_view_search_backward (GtrView * view,
   while (!found)
     {
       found = gtk_text_iter_backward_search (&iter,
-                                             view->priv->search_text,
+                                             priv->search_text,
                                              search_flags,
                                              &m_start, &m_end, start);
 
-      if (found && GTR_SEARCH_IS_ENTIRE_WORD (view->priv->search_flags))
+      if (found && GTR_SEARCH_IS_ENTIRE_WORD (priv->search_flags))
         {
           found = gtk_text_iter_starts_word (&m_start) &&
             gtk_text_iter_ends_word (&m_end);
@@ -713,6 +747,7 @@ gtr_view_replace_all (GtrView * view,
   GtkTextIter m_start;
   GtkTextIter m_end;
   GtkTextSearchFlags search_flags = 0;
+  GtrViewPrivate *priv;
   gboolean found = TRUE;
   gint cont = 0;
   gchar *search_text;
@@ -724,12 +759,14 @@ gtr_view_replace_all (GtrView * view,
 
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 
+  priv = gtr_view_get_instance_private (view);
+
   g_return_val_if_fail (replace != NULL, 0);
   g_return_val_if_fail ((find != NULL)
-                        || (view->priv->search_text != NULL), 0);
+                        || (priv->search_text != NULL), 0);
 
   if (find == NULL)
-    search_text = g_strdup (view->priv->search_text);
+    search_text = g_strdup (priv->search_text);
   else
     search_text = gtr_utils_unescape_search_text (find);
 
@@ -750,7 +787,7 @@ gtr_view_replace_all (GtrView * view,
    * replace_all so that we don't spend all the time
    * updating the position in the statusbar
    */
-  //view->priv->stop_cursor_moved_emission = TRUE;
+  //priv->stop_cursor_moved_emission = TRUE;
 
   gtk_text_buffer_begin_user_action (buffer);
 
@@ -794,7 +831,7 @@ gtr_view_replace_all (GtrView * view,
   /* re-enable cursor_moved emission and notify
    * the current position 
    */
-  //view->priv->stop_cursor_moved_emission = FALSE;
+  //priv->stop_cursor_moved_emission = FALSE;
   //emit_cursor_moved (GTK_SOURCE_BUFFER(buffer));
 
   g_free (search_text);
@@ -816,12 +853,15 @@ gtr_view_reload_scheme_color (GtrView * view)
   GtkSourceBuffer *buf;
   GtkSourceStyleScheme *scheme;
   GtkSourceStyleSchemeManager *manager;
+  GtrViewPrivate *priv;
   gchar *scheme_id;
 
+  priv = gtr_view_get_instance_private (view);
+
   buf = GTK_SOURCE_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
   manager = gtk_source_style_scheme_manager_get_default ();
 
-  scheme_id = g_settings_get_string (view->priv->ui_settings,
+  scheme_id = g_settings_get_string (priv->ui_settings,
                                      GTR_SETTINGS_COLOR_SCHEME);
   scheme = gtk_source_style_scheme_manager_get_scheme (manager, scheme_id);
   g_free (scheme_id);
