@@ -64,7 +64,7 @@ setup_path (void)
   g_free (bin);
 
   if (!g_setenv ("PATH", path, TRUE))
-    g_warning ("Could not set PATH for gtranslator");
+    g_warning ("Could not set PATH for Translation Editor");
 
   g_free (path);
 }
@@ -77,9 +77,6 @@ main (gint argc, gchar * argv[])
   GtrApplication *app;
   gint status;
 
-  /* Init type system and threads as soon as possible */
-  g_type_init ();
-
   gtr_dirs_init ();
 
   /* Initialize gettext. */
@@ -97,11 +94,11 @@ main (gint argc, gchar * argv[])
   GOptionContext *context;
   GError *error = NULL;
 
-  context = g_option_context_new (_("- Edit PO files"));
+  context = g_option_context_new (_("— Edit PO files"));
   g_option_context_add_group (context, g_irepository_get_option_group ());
   if (!g_option_context_parse (context, &argc, &argv, &error))
     {
-      g_print(_("%s\nRun '%s --help' to see a full list of available command line options.\n"),
+      g_print(_("%s\nRun “%s --help” to see a full list of available command line options.\n"),
               error->message, argv[0]);
       g_error_free (error);
       g_option_context_free (context);
